# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cacheclient.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63\x61\x63heclient.proto\x12\x0c\x63\x61\x63he_client\x1a\x0c\x63ommon.proto\" \n\x0b_GetRequest\x12\x11\n\tcache_key\x18\x01 \x01(\x0c\"_\n\x0c_GetResponse\x12*\n\x06result\x18\x01 \x01(\x0e\x32\x1a.cache_client.ECacheResult\x12\x12\n\ncache_body\x18\x02 \x01(\x0c\x12\x0f\n\x07message\x18\x03 \x01(\t\"<\n\x10_GetBatchRequest\x12(\n\x05items\x18\x01 \x03(\x0b\x32\x19.cache_client._GetRequest\"#\n\x0e_DeleteRequest\x12\x11\n\tcache_key\x18\x01 \x01(\x0c\"\x11\n\x0f_DeleteResponse\"N\n\x0b_SetRequest\x12\x11\n\tcache_key\x18\x01 \x01(\x0c\x12\x12\n\ncache_body\x18\x02 \x01(\x0c\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\"K\n\x0c_SetResponse\x12*\n\x06result\x18\x01 \x01(\x0e\x32\x1a.cache_client.ECacheResult\x12\x0f\n\x07message\x18\x02 \x01(\t\"<\n\x10_SetBatchRequest\x12(\n\x05items\x18\x01 \x03(\x0b\x32\x19.cache_client._SetRequest\"\xd9\x02\n\r_SetIfRequest\x12\x11\n\tcache_key\x18\x01 \x01(\x0c\x12\x12\n\ncache_body\x18\x02 \x01(\x0c\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\x12\"\n\x07present\x18\x04 \x01(\x0b\x32\x0f.common.PresentH\x00\x12;\n\x15present_and_not_equal\x18\x05 \x01(\x0b\x32\x1a.common.PresentAndNotEqualH\x00\x12 \n\x06\x61\x62sent\x18\x06 \x01(\x0b\x32\x0e.common.AbsentH\x00\x12\x1e\n\x05\x65qual\x18\x07 \x01(\x0b\x32\r.common.EqualH\x00\x12\x30\n\x0f\x61\x62sent_or_equal\x18\x08 \x01(\x0b\x32\x15.common.AbsentOrEqualH\x00\x12%\n\tnot_equal\x18\t \x01(\x0b\x32\x10.common.NotEqualH\x00\x42\x0b\n\tcondition\"\xaa\x01\n\x0e_SetIfResponse\x12\x36\n\x06stored\x18\x01 \x01(\x0b\x32$.cache_client._SetIfResponse._StoredH\x00\x12=\n\nnot_stored\x18\x02 \x01(\x0b\x32\'.cache_client._SetIfResponse._NotStoredH\x00\x1a\t\n\x07_Stored\x1a\x0c\n\n_NotStoredB\x08\n\x06result\"Y\n\x16_SetIfNotExistsRequest\x12\x11\n\tcache_key\x18\x01 \x01(\x0c\x12\x12\n\ncache_body\x18\x02 \x01(\x0c\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\"\xc5\x01\n\x17_SetIfNotExistsResponse\x12?\n\x06stored\x18\x01 \x01(\x0b\x32-.cache_client._SetIfNotExistsResponse._StoredH\x00\x12\x46\n\nnot_stored\x18\x02 \x01(\x0b\x32\x30.cache_client._SetIfNotExistsResponse._NotStoredH\x00\x1a\t\n\x07_Stored\x1a\x0c\n\n_NotStoredB\x08\n\x06result\"\'\n\x11_KeysExistRequest\x12\x12\n\ncache_keys\x18\x01 \x03(\x0c\"$\n\x12_KeysExistResponse\x12\x0e\n\x06\x65xists\x18\x01 \x03(\x08\"P\n\x11_IncrementRequest\x12\x11\n\tcache_key\x18\x01 \x01(\x0c\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x03\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\"#\n\x12_IncrementResponse\x12\r\n\x05value\x18\x01 \x01(\x03\"\xa1\x01\n\x11_UpdateTtlRequest\x12\x11\n\tcache_key\x18\x01 \x01(\x0c\x12\"\n\x18increase_to_milliseconds\x18\x02 \x01(\x04H\x00\x12\"\n\x18\x64\x65\x63rease_to_milliseconds\x18\x03 \x01(\x04H\x00\x12#\n\x19overwrite_to_milliseconds\x18\x04 \x01(\x04H\x00\x42\x0c\n\nupdate_ttl\"\xee\x01\n\x12_UpdateTtlResponse\x12\x34\n\x03set\x18\x01 \x01(\x0b\x32%.cache_client._UpdateTtlResponse._SetH\x00\x12;\n\x07not_set\x18\x02 \x01(\x0b\x32(.cache_client._UpdateTtlResponse._NotSetH\x00\x12<\n\x07missing\x18\x03 \x01(\x0b\x32).cache_client._UpdateTtlResponse._MissingH\x00\x1a\x06\n\x04_Set\x1a\t\n\x07_NotSet\x1a\n\n\x08_MissingB\x08\n\x06result\"\'\n\x12_ItemGetTtlRequest\x12\x11\n\tcache_key\x18\x01 \x01(\x0c\"\xcd\x01\n\x13_ItemGetTtlResponse\x12\x39\n\x05\x66ound\x18\x01 \x01(\x0b\x32(.cache_client._ItemGetTtlResponse._FoundH\x00\x12=\n\x07missing\x18\x02 \x01(\x0b\x32*.cache_client._ItemGetTtlResponse._MissingH\x00\x1a&\n\x06_Found\x12\x1c\n\x14remaining_ttl_millis\x18\x01 \x01(\x04\x1a\n\n\x08_MissingB\x08\n\x06result\"(\n\x13_ItemGetTypeRequest\x12\x11\n\tcache_key\x18\x01 \x01(\x0c\"\xbd\x02\n\x14_ItemGetTypeResponse\x12:\n\x05\x66ound\x18\x01 \x01(\x0b\x32).cache_client._ItemGetTypeResponse._FoundH\x00\x12>\n\x07missing\x18\x02 \x01(\x0b\x32+.cache_client._ItemGetTypeResponse._MissingH\x00\x1aH\n\x06_Found\x12>\n\titem_type\x18\x01 \x01(\x0e\x32+.cache_client._ItemGetTypeResponse.ItemType\x1a\n\n\x08_Missing\"I\n\x08ItemType\x12\n\n\x06SCALAR\x10\x00\x12\x0e\n\nDICTIONARY\x10\x01\x12\x07\n\x03SET\x10\x02\x12\x08\n\x04LIST\x10\x03\x12\x0e\n\nSORTED_SET\x10\x04\x42\x08\n\x06result\"@\n\x15_DictionaryGetRequest\x12\x17\n\x0f\x64ictionary_name\x18\x01 \x01(\x0c\x12\x0e\n\x06\x66ields\x18\x02 \x03(\x0c\"\xea\x02\n\x16_DictionaryGetResponse\x12<\n\x05\x66ound\x18\x01 \x01(\x0b\x32+.cache_client._DictionaryGetResponse._FoundH\x00\x12@\n\x07missing\x18\x02 \x01(\x0b\x32-.cache_client._DictionaryGetResponse._MissingH\x00\x1a\\\n\x1a_DictionaryGetResponsePart\x12*\n\x06result\x18\x01 \x01(\x0e\x32\x1a.cache_client.ECacheResult\x12\x12\n\ncache_body\x18\x02 \x01(\x0c\x1aX\n\x06_Found\x12N\n\x05items\x18\x01 \x03(\x0b\x32?.cache_client._DictionaryGetResponse._DictionaryGetResponsePart\x1a\n\n\x08_MissingB\x0c\n\ndictionary\"2\n\x17_DictionaryFetchRequest\x12\x17\n\x0f\x64ictionary_name\x18\x01 \x01(\x0c\"9\n\x19_DictionaryFieldValuePair\x12\r\n\x05\x66ield\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\"\xfa\x01\n\x18_DictionaryFetchResponse\x12>\n\x05\x66ound\x18\x01 \x01(\x0b\x32-.cache_client._DictionaryFetchResponse._FoundH\x00\x12\x42\n\x07missing\x18\x02 \x01(\x0b\x32/.cache_client._DictionaryFetchResponse._MissingH\x00\x1a@\n\x06_Found\x12\x36\n\x05items\x18\x01 \x03(\x0b\x32\'.cache_client._DictionaryFieldValuePair\x1a\n\n\x08_MissingB\x0c\n\ndictionary\"\x97\x01\n\x15_DictionarySetRequest\x12\x17\n\x0f\x64ictionary_name\x18\x01 \x01(\x0c\x12\x36\n\x05items\x18\x02 \x03(\x0b\x32\'.cache_client._DictionaryFieldValuePair\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x04 \x01(\x08\"\x18\n\x16_DictionarySetResponse\"\x84\x01\n\x1b_DictionaryIncrementRequest\x12\x17\n\x0f\x64ictionary_name\x18\x01 \x01(\x0c\x12\r\n\x05\x66ield\x18\x02 \x01(\x0c\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x03\x12\x18\n\x10ttl_milliseconds\x18\x04 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x05 \x01(\x08\"-\n\x1c_DictionaryIncrementResponse\x12\r\n\x05value\x18\x01 \x01(\x03\"\xd4\x01\n\x18_DictionaryDeleteRequest\x12\x17\n\x0f\x64ictionary_name\x18\x01 \x01(\x0c\x12;\n\x04some\x18\x02 \x01(\x0b\x32+.cache_client._DictionaryDeleteRequest.SomeH\x00\x12\x39\n\x03\x61ll\x18\x03 \x01(\x0b\x32*.cache_client._DictionaryDeleteRequest.AllH\x00\x1a\x16\n\x04Some\x12\x0e\n\x06\x66ields\x18\x01 \x03(\x0c\x1a\x05\n\x03\x41llB\x08\n\x06\x64\x65lete\"\x1b\n\x19_DictionaryDeleteResponse\"3\n\x18_DictionaryLengthRequest\x12\x17\n\x0f\x64ictionary_name\x18\x01 \x01(\x0c\"\xd5\x01\n\x19_DictionaryLengthResponse\x12?\n\x05\x66ound\x18\x01 \x01(\x0b\x32..cache_client._DictionaryLengthResponse._FoundH\x00\x12\x43\n\x07missing\x18\x02 \x01(\x0b\x32\x30.cache_client._DictionaryLengthResponse._MissingH\x00\x1a\x18\n\x06_Found\x12\x0e\n\x06length\x18\x01 \x01(\r\x1a\n\n\x08_MissingB\x0c\n\ndictionary\"$\n\x10_SetFetchRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\"\xb8\x01\n\x11_SetFetchResponse\x12\x37\n\x05\x66ound\x18\x01 \x01(\x0b\x32&.cache_client._SetFetchResponse._FoundH\x00\x12;\n\x07missing\x18\x02 \x01(\x0b\x32(.cache_client._SetFetchResponse._MissingH\x00\x1a\x1a\n\x06_Found\x12\x10\n\x08\x65lements\x18\x01 \x03(\x0c\x1a\n\n\x08_MissingB\x05\n\x03set\"4\n\x11_SetSampleRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\r\n\x05limit\x18\x02 \x01(\x04\"\xbb\x01\n\x12_SetSampleResponse\x12\x38\n\x05\x66ound\x18\x01 \x01(\x0b\x32\'.cache_client._SetSampleResponse._FoundH\x00\x12<\n\x07missing\x18\x02 \x01(\x0b\x32).cache_client._SetSampleResponse._MissingH\x00\x1a\x1a\n\x06_Found\x12\x10\n\x08\x65lements\x18\x01 \x03(\x0c\x1a\n\n\x08_MissingB\x05\n\x03set\"e\n\x10_SetUnionRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\x10\n\x08\x65lements\x18\x02 \x03(\x0c\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x04 \x01(\x08\"\x13\n\x11_SetUnionResponse\"\xba\x03\n\x15_SetDifferenceRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12?\n\x07minuend\x18\x02 \x01(\x0b\x32,.cache_client._SetDifferenceRequest._MinuendH\x00\x12\x45\n\nsubtrahend\x18\x03 \x01(\x0b\x32/.cache_client._SetDifferenceRequest._SubtrahendH\x00\x1a\x1c\n\x08_Minuend\x12\x10\n\x08\x65lements\x18\x01 \x03(\x0c\x1a\xda\x01\n\x0b_Subtrahend\x12\x43\n\x03set\x18\x01 \x01(\x0b\x32\x34.cache_client._SetDifferenceRequest._Subtrahend._SetH\x00\x12M\n\x08identity\x18\x02 \x01(\x0b\x32\x39.cache_client._SetDifferenceRequest._Subtrahend._IdentityH\x00\x1a\x18\n\x04_Set\x12\x10\n\x08\x65lements\x18\x01 \x03(\x0c\x1a\x0b\n\t_IdentityB\x10\n\x0esubtrahend_setB\x0c\n\ndifference\"\xb5\x01\n\x16_SetDifferenceResponse\x12<\n\x05\x66ound\x18\x01 \x01(\x0b\x32+.cache_client._SetDifferenceResponse._FoundH\x00\x12@\n\x07missing\x18\x02 \x01(\x0b\x32-.cache_client._SetDifferenceResponse._MissingH\x00\x1a\x08\n\x06_Found\x1a\n\n\x08_MissingB\x05\n\x03set\"9\n\x13_SetContainsRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\x10\n\x08\x65lements\x18\x02 \x03(\x0c\"\xc1\x01\n\x14_SetContainsResponse\x12:\n\x05\x66ound\x18\x01 \x01(\x0b\x32).cache_client._SetContainsResponse._FoundH\x00\x12>\n\x07missing\x18\x02 \x01(\x0b\x32+.cache_client._SetContainsResponse._MissingH\x00\x1a\x1a\n\x06_Found\x12\x10\n\x08\x63ontains\x18\x01 \x03(\x08\x1a\n\n\x08_MissingB\x05\n\x03set\"%\n\x11_SetLengthRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\"\xb9\x01\n\x12_SetLengthResponse\x12\x38\n\x05\x66ound\x18\x01 \x01(\x0b\x32\'.cache_client._SetLengthResponse._FoundH\x00\x12<\n\x07missing\x18\x02 \x01(\x0b\x32).cache_client._SetLengthResponse._MissingH\x00\x1a\x18\n\x06_Found\x12\x0e\n\x06length\x18\x01 \x01(\r\x1a\n\n\x08_MissingB\x05\n\x03set\"1\n\x0e_SetPopRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"\xb2\x01\n\x0f_SetPopResponse\x12\x35\n\x05\x66ound\x18\x01 \x01(\x0b\x32$.cache_client._SetPopResponse._FoundH\x00\x12\x39\n\x07missing\x18\x02 \x01(\x0b\x32&.cache_client._SetPopResponse._MissingH\x00\x1a\x1a\n\x06_Found\x12\x10\n\x08\x65lements\x18\x01 \x03(\x0c\x1a\n\n\x08_MissingB\x05\n\x03set\"\x8f\x01\n\x1c_ListConcatenateFrontRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\x12\x0e\n\x06values\x18\x02 \x03(\x0c\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x04 \x01(\x08\x12\x1d\n\x15truncate_back_to_size\x18\x05 \x01(\r\"4\n\x1d_ListConcatenateFrontResponse\x12\x13\n\x0blist_length\x18\x01 \x01(\r\"\x8f\x01\n\x1b_ListConcatenateBackRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\x12\x0e\n\x06values\x18\x02 \x03(\x0c\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x04 \x01(\x08\x12\x1e\n\x16truncate_front_to_size\x18\x05 \x01(\r\"3\n\x1c_ListConcatenateBackResponse\x12\x13\n\x0blist_length\x18\x01 \x01(\r\"\x87\x01\n\x15_ListPushFrontRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x04 \x01(\x08\x12\x1d\n\x15truncate_back_to_size\x18\x05 \x01(\r\"-\n\x16_ListPushFrontResponse\x12\x13\n\x0blist_length\x18\x01 \x01(\r\"\x87\x01\n\x14_ListPushBackRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x04 \x01(\x08\x12\x1e\n\x16truncate_front_to_size\x18\x05 \x01(\r\",\n\x15_ListPushBackResponse\x12\x13\n\x0blist_length\x18\x01 \x01(\r\")\n\x14_ListPopFrontRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\"\xd7\x01\n\x15_ListPopFrontResponse\x12;\n\x05\x66ound\x18\x01 \x01(\x0b\x32*.cache_client._ListPopFrontResponse._FoundH\x00\x12?\n\x07missing\x18\x02 \x01(\x0b\x32,.cache_client._ListPopFrontResponse._MissingH\x00\x1a,\n\x06_Found\x12\r\n\x05\x66ront\x18\x01 \x01(\x0c\x12\x13\n\x0blist_length\x18\x02 \x01(\r\x1a\n\n\x08_MissingB\x06\n\x04list\"(\n\x13_ListPopBackRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\"\xd3\x01\n\x14_ListPopBackResponse\x12:\n\x05\x66ound\x18\x01 \x01(\x0b\x32).cache_client._ListPopBackResponse._FoundH\x00\x12>\n\x07missing\x18\x02 \x01(\x0b\x32+.cache_client._ListPopBackResponse._MissingH\x00\x1a+\n\x06_Found\x12\x0c\n\x04\x62\x61\x63k\x18\x01 \x01(\x0c\x12\x13\n\x0blist_length\x18\x02 \x01(\r\x1a\n\n\x08_MissingB\x06\n\x04list\"0\n\n_ListRange\x12\x13\n\x0b\x62\x65gin_index\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"\xe2\x01\n\x11_ListEraseRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\x12;\n\x04some\x18\x02 \x01(\x0b\x32+.cache_client._ListEraseRequest._ListRangesH\x00\x12\x33\n\x03\x61ll\x18\x03 \x01(\x0b\x32$.cache_client._ListEraseRequest._AllH\x00\x1a\x06\n\x04_All\x1a\x37\n\x0b_ListRanges\x12(\n\x06ranges\x18\x01 \x03(\x0b\x32\x18.cache_client._ListRangeB\x07\n\x05\x65rase\"\xbf\x01\n\x12_ListEraseResponse\x12\x38\n\x05\x66ound\x18\x01 \x01(\x0b\x32\'.cache_client._ListEraseResponse._FoundH\x00\x12<\n\x07missing\x18\x02 \x01(\x0b\x32).cache_client._ListEraseResponse._MissingH\x00\x1a\x1d\n\x06_Found\x12\x13\n\x0blist_length\x18\x01 \x01(\r\x1a\n\n\x08_MissingB\x06\n\x04list\"T\n\x12_ListRemoveRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\x12!\n\x17\x61ll_elements_with_value\x18\x02 \x01(\x0cH\x00\x42\x08\n\x06remove\"\xc2\x01\n\x13_ListRemoveResponse\x12\x39\n\x05\x66ound\x18\x01 \x01(\x0b\x32(.cache_client._ListRemoveResponse._FoundH\x00\x12=\n\x07missing\x18\x02 \x01(\x0b\x32*.cache_client._ListRemoveResponse._MissingH\x00\x1a\x1d\n\x06_Found\x12\x13\n\x0blist_length\x18\x01 \x01(\r\x1a\n\n\x08_MissingB\x06\n\x04list\"\xd2\x01\n\x11_ListFetchRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\x12-\n\x0funbounded_start\x18\x02 \x01(\x0b\x32\x12.common._UnboundedH\x00\x12\x19\n\x0finclusive_start\x18\x03 \x01(\x11H\x00\x12+\n\runbounded_end\x18\x04 \x01(\x0b\x32\x12.common._UnboundedH\x01\x12\x17\n\rexclusive_end\x18\x05 \x01(\x11H\x01\x42\r\n\x0bstart_indexB\x0b\n\tend_index\"\x82\x02\n\x12_ListRetainRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\x12-\n\x0funbounded_start\x18\x02 \x01(\x0b\x32\x12.common._UnboundedH\x00\x12\x19\n\x0finclusive_start\x18\x03 \x01(\x11H\x00\x12+\n\runbounded_end\x18\x04 \x01(\x0b\x32\x12.common._UnboundedH\x01\x12\x17\n\rexclusive_end\x18\x05 \x01(\x11H\x01\x12\x18\n\x10ttl_milliseconds\x18\x06 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x07 \x01(\x08\x42\r\n\x0bstart_indexB\x0b\n\tend_index\"\xc2\x01\n\x13_ListRetainResponse\x12\x39\n\x05\x66ound\x18\x01 \x01(\x0b\x32(.cache_client._ListRetainResponse._FoundH\x00\x12=\n\x07missing\x18\x02 \x01(\x0b\x32*.cache_client._ListRetainResponse._MissingH\x00\x1a\x1d\n\x06_Found\x12\x13\n\x0blist_length\x18\x01 \x01(\r\x1a\n\n\x08_MissingB\x06\n\x04list\"\xba\x01\n\x12_ListFetchResponse\x12\x38\n\x05\x66ound\x18\x01 \x01(\x0b\x32\'.cache_client._ListFetchResponse._FoundH\x00\x12<\n\x07missing\x18\x02 \x01(\x0b\x32).cache_client._ListFetchResponse._MissingH\x00\x1a\x18\n\x06_Found\x12\x0e\n\x06values\x18\x01 \x03(\x0c\x1a\n\n\x08_MissingB\x06\n\x04list\"\'\n\x12_ListLengthRequest\x12\x11\n\tlist_name\x18\x01 \x01(\x0c\"\xbd\x01\n\x13_ListLengthResponse\x12\x39\n\x05\x66ound\x18\x01 \x01(\x0b\x32(.cache_client._ListLengthResponse._FoundH\x00\x12=\n\x07missing\x18\x02 \x01(\x0b\x32*.cache_client._ListLengthResponse._MissingH\x00\x1a\x18\n\x06_Found\x12\x0e\n\x06length\x18\x01 \x01(\r\x1a\n\n\x08_MissingB\x06\n\x04list\"1\n\x11_SortedSetElement\x12\r\n\x05value\x18\x01 \x01(\x0c\x12\r\n\x05score\x18\x02 \x01(\x01\"\x8a\x01\n\x14_SortedSetPutRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\x31\n\x08\x65lements\x18\x02 \x03(\x0b\x32\x1f.cache_client._SortedSetElement\x12\x18\n\x10ttl_milliseconds\x18\x03 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x04 \x01(\x08\"\x17\n\x15_SortedSetPutResponse\"\xc0\x06\n\x16_SortedSetFetchRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\x39\n\x05order\x18\x02 \x01(\x0e\x32*.cache_client._SortedSetFetchRequest.Order\x12\x13\n\x0bwith_scores\x18\x03 \x01(\x08\x12\x41\n\x08\x62y_index\x18\x04 \x01(\x0b\x32-.cache_client._SortedSetFetchRequest._ByIndexH\x00\x12\x41\n\x08\x62y_score\x18\x05 \x01(\x0b\x32-.cache_client._SortedSetFetchRequest._ByScoreH\x00\x1a\xb6\x01\n\x08_ByIndex\x12-\n\x0funbounded_start\x18\x01 \x01(\x0b\x32\x12.common._UnboundedH\x00\x12\x1f\n\x15inclusive_start_index\x18\x02 \x01(\x11H\x00\x12+\n\runbounded_end\x18\x03 \x01(\x0b\x32\x12.common._UnboundedH\x01\x12\x1d\n\x13\x65xclusive_end_index\x18\x04 \x01(\x11H\x01\x42\x07\n\x05startB\x05\n\x03\x65nd\x1a\xd3\x02\n\x08_ByScore\x12+\n\runbounded_min\x18\x01 \x01(\x0b\x32\x12.common._UnboundedH\x00\x12I\n\tmin_score\x18\x02 \x01(\x0b\x32\x34.cache_client._SortedSetFetchRequest._ByScore._ScoreH\x00\x12+\n\runbounded_max\x18\x03 \x01(\x0b\x32\x12.common._UnboundedH\x01\x12I\n\tmax_score\x18\x04 \x01(\x0b\x32\x34.cache_client._SortedSetFetchRequest._ByScore._ScoreH\x01\x12\x0e\n\x06offset\x18\x05 \x01(\r\x12\r\n\x05\x63ount\x18\x06 \x01(\x11\x1a*\n\x06_Score\x12\r\n\x05score\x18\x01 \x01(\x01\x12\x11\n\texclusive\x18\x02 \x01(\x08\x42\x05\n\x03minB\x05\n\x03max\"&\n\x05Order\x12\r\n\tASCENDING\x10\x00\x12\x0e\n\nDESCENDING\x10\x01\x42\x07\n\x05range\"\xd5\x03\n\x17_SortedSetFetchResponse\x12=\n\x05\x66ound\x18\x01 \x01(\x0b\x32,.cache_client._SortedSetFetchResponse._FoundH\x00\x12\x41\n\x07missing\x18\x02 \x01(\x0b\x32..cache_client._SortedSetFetchResponse._MissingH\x00\x1a\x9d\x02\n\x06_Found\x12\\\n\x12values_with_scores\x18\x01 \x01(\x0b\x32>.cache_client._SortedSetFetchResponse._Found._ValuesWithScoresH\x00\x12\x46\n\x06values\x18\x02 \x01(\x0b\x32\x34.cache_client._SortedSetFetchResponse._Found._ValuesH\x00\x1a\x46\n\x11_ValuesWithScores\x12\x31\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x1f.cache_client._SortedSetElement\x1a\x19\n\x07_Values\x12\x0e\n\x06values\x18\x01 \x03(\x0c\x42\n\n\x08\x65lements\x1a\n\n\x08_MissingB\x0c\n\nsorted_set\"=\n\x19_SortedSetGetScoreRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\x0e\n\x06values\x18\x02 \x03(\x0c\"\xa4\x03\n\x1a_SortedSetGetScoreResponse\x12I\n\x05\x66ound\x18\x01 \x01(\x0b\x32\x38.cache_client._SortedSetGetScoreResponse._SortedSetFoundH\x00\x12M\n\x07missing\x18\x02 \x01(\x0b\x32:.cache_client._SortedSetGetScoreResponse._SortedSetMissingH\x00\x1a[\n\x1e_SortedSetGetScoreResponsePart\x12*\n\x06result\x18\x01 \x01(\x0e\x32\x1a.cache_client.ECacheResult\x12\r\n\x05score\x18\x02 \x01(\x01\x1al\n\x0f_SortedSetFound\x12Y\n\x08\x65lements\x18\x01 \x03(\x0b\x32G.cache_client._SortedSetGetScoreResponse._SortedSetGetScoreResponsePart\x1a\x13\n\x11_SortedSetMissingB\x0c\n\nsorted_set\"\xd7\x01\n\x17_SortedSetRemoveRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\x39\n\x03\x61ll\x18\x02 \x01(\x0b\x32*.cache_client._SortedSetRemoveRequest._AllH\x00\x12;\n\x04some\x18\x03 \x01(\x0b\x32+.cache_client._SortedSetRemoveRequest._SomeH\x00\x1a\x06\n\x04_All\x1a\x17\n\x05_Some\x12\x0e\n\x06values\x18\x01 \x03(\x0c\x42\x11\n\x0fremove_elements\"\x1a\n\x18_SortedSetRemoveResponse\"|\n\x1a_SortedSetIncrementRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x01\x12\x18\n\x10ttl_milliseconds\x18\x04 \x01(\x04\x12\x13\n\x0brefresh_ttl\x18\x05 \x01(\x08\",\n\x1b_SortedSetIncrementResponse\x12\r\n\x05score\x18\x01 \x01(\x01\"\xa0\x01\n\x18_SortedSetGetRankRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12;\n\x05order\x18\x03 \x01(\x0e\x32,.cache_client._SortedSetGetRankRequest.Order\"&\n\x05Order\x12\r\n\tASCENDING\x10\x00\x12\x0e\n\nDESCENDING\x10\x01\"\xa8\x02\n\x19_SortedSetGetRankResponse\x12Q\n\x0c\x65lement_rank\x18\x01 \x01(\x0b\x32\x39.cache_client._SortedSetGetRankResponse._RankResponsePartH\x00\x12L\n\x07missing\x18\x02 \x01(\x0b\x32\x39.cache_client._SortedSetGetRankResponse._SortedSetMissingH\x00\x1aM\n\x11_RankResponsePart\x12*\n\x06result\x18\x01 \x01(\x0e\x32\x1a.cache_client.ECacheResult\x12\x0c\n\x04rank\x18\x02 \x01(\x04\x1a\x13\n\x11_SortedSetMissingB\x06\n\x04rank\"+\n\x17_SortedSetLengthRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\"\xd2\x01\n\x18_SortedSetLengthResponse\x12>\n\x05\x66ound\x18\x01 \x01(\x0b\x32-.cache_client._SortedSetLengthResponse._FoundH\x00\x12\x42\n\x07missing\x18\x02 \x01(\x0b\x32/.cache_client._SortedSetLengthResponse._MissingH\x00\x1a\x18\n\x06_Found\x12\x0e\n\x06length\x18\x01 \x01(\r\x1a\n\n\x08_MissingB\x0c\n\nsorted_set\"\xfe\x01\n\x1e_SortedSetLengthByScoreRequest\x12\x10\n\x08set_name\x18\x01 \x01(\x0c\x12\x17\n\rinclusive_min\x18\x02 \x01(\x01H\x00\x12\x17\n\rexclusive_min\x18\x03 \x01(\x01H\x00\x12+\n\runbounded_min\x18\x04 \x01(\x0b\x32\x12.common._UnboundedH\x00\x12\x17\n\rinclusive_max\x18\x05 \x01(\x01H\x01\x12\x17\n\rexclusive_max\x18\x06 \x01(\x01H\x01\x12+\n\runbounded_max\x18\x07 \x01(\x0b\x32\x12.common._UnboundedH\x01\x42\x05\n\x03minB\x05\n\x03max\"\xe7\x01\n\x1f_SortedSetLengthByScoreResponse\x12\x45\n\x05\x66ound\x18\x01 \x01(\x0b\x32\x34.cache_client._SortedSetLengthByScoreResponse._FoundH\x00\x12I\n\x07missing\x18\x02 \x01(\x0b\x32\x36.cache_client._SortedSetLengthByScoreResponse._MissingH\x00\x1a\x18\n\x06_Found\x12\x0e\n\x06length\x18\x01 \x01(\r\x1a\n\n\x08_MissingB\x0c\n\nsorted_set*<\n\x0c\x45\x43\x61\x63heResult\x12\x0b\n\x07Invalid\x10\x00\x12\x06\n\x02Ok\x10\x01\x12\x07\n\x03Hit\x10\x02\x12\x08\n\x04Miss\x10\x03\"\x04\x08\x04\x10\x06\x32\xff\x1e\n\x03Scs\x12>\n\x03Get\x12\x19.cache_client._GetRequest\x1a\x1a.cache_client._GetResponse\"\x00\x12J\n\x08GetBatch\x12\x1e.cache_client._GetBatchRequest\x1a\x1a.cache_client._GetResponse\"\x00\x30\x01\x12>\n\x03Set\x12\x19.cache_client._SetRequest\x1a\x1a.cache_client._SetResponse\"\x00\x12J\n\x08SetBatch\x12\x1e.cache_client._SetBatchRequest\x1a\x1a.cache_client._SetResponse\"\x00\x30\x01\x12\x44\n\x05SetIf\x12\x1b.cache_client._SetIfRequest\x1a\x1c.cache_client._SetIfResponse\"\x00\x12\x62\n\x0eSetIfNotExists\x12$.cache_client._SetIfNotExistsRequest\x1a%.cache_client._SetIfNotExistsResponse\"\x03\x88\x02\x01\x12G\n\x06\x44\x65lete\x12\x1c.cache_client._DeleteRequest\x1a\x1d.cache_client._DeleteResponse\"\x00\x12P\n\tKeysExist\x12\x1f.cache_client._KeysExistRequest\x1a .cache_client._KeysExistResponse\"\x00\x12P\n\tIncrement\x12\x1f.cache_client._IncrementRequest\x1a .cache_client._IncrementResponse\"\x00\x12P\n\tUpdateTtl\x12\x1f.cache_client._UpdateTtlRequest\x1a .cache_client._UpdateTtlResponse\"\x00\x12S\n\nItemGetTtl\x12 .cache_client._ItemGetTtlRequest\x1a!.cache_client._ItemGetTtlResponse\"\x00\x12V\n\x0bItemGetType\x12!.cache_client._ItemGetTypeRequest\x1a\".cache_client._ItemGetTypeResponse\"\x00\x12\\\n\rDictionaryGet\x12#.cache_client._DictionaryGetRequest\x1a$.cache_client._DictionaryGetResponse\"\x00\x12\x62\n\x0f\x44ictionaryFetch\x12%.cache_client._DictionaryFetchRequest\x1a&.cache_client._DictionaryFetchResponse\"\x00\x12\\\n\rDictionarySet\x12#.cache_client._DictionarySetRequest\x1a$.cache_client._DictionarySetResponse\"\x00\x12n\n\x13\x44ictionaryIncrement\x12).cache_client._DictionaryIncrementRequest\x1a*.cache_client._DictionaryIncrementResponse\"\x00\x12\x65\n\x10\x44ictionaryDelete\x12&.cache_client._DictionaryDeleteRequest\x1a\'.cache_client._DictionaryDeleteResponse\"\x00\x12\x65\n\x10\x44ictionaryLength\x12&.cache_client._DictionaryLengthRequest\x1a\'.cache_client._DictionaryLengthResponse\"\x00\x12M\n\x08SetFetch\x12\x1e.cache_client._SetFetchRequest\x1a\x1f.cache_client._SetFetchResponse\"\x00\x12P\n\tSetSample\x12\x1f.cache_client._SetSampleRequest\x1a .cache_client._SetSampleResponse\"\x00\x12M\n\x08SetUnion\x12\x1e.cache_client._SetUnionRequest\x1a\x1f.cache_client._SetUnionResponse\"\x00\x12\\\n\rSetDifference\x12#.cache_client._SetDifferenceRequest\x1a$.cache_client._SetDifferenceResponse\"\x00\x12V\n\x0bSetContains\x12!.cache_client._SetContainsRequest\x1a\".cache_client._SetContainsResponse\"\x00\x12P\n\tSetLength\x12\x1f.cache_client._SetLengthRequest\x1a .cache_client._SetLengthResponse\"\x00\x12G\n\x06SetPop\x12\x1c.cache_client._SetPopRequest\x1a\x1d.cache_client._SetPopResponse\"\x00\x12\\\n\rListPushFront\x12#.cache_client._ListPushFrontRequest\x1a$.cache_client._ListPushFrontResponse\"\x00\x12Y\n\x0cListPushBack\x12\".cache_client._ListPushBackRequest\x1a#.cache_client._ListPushBackResponse\"\x00\x12Y\n\x0cListPopFront\x12\".cache_client._ListPopFrontRequest\x1a#.cache_client._ListPopFrontResponse\"\x00\x12V\n\x0bListPopBack\x12!.cache_client._ListPopBackRequest\x1a\".cache_client._ListPopBackResponse\"\x00\x12P\n\tListErase\x12\x1f.cache_client._ListEraseRequest\x1a .cache_client._ListEraseResponse\"\x00\x12S\n\nListRemove\x12 .cache_client._ListRemoveRequest\x1a!.cache_client._ListRemoveResponse\"\x00\x12P\n\tListFetch\x12\x1f.cache_client._ListFetchRequest\x1a .cache_client._ListFetchResponse\"\x00\x12S\n\nListLength\x12 .cache_client._ListLengthRequest\x1a!.cache_client._ListLengthResponse\"\x00\x12q\n\x14ListConcatenateFront\x12*.cache_client._ListConcatenateFrontRequest\x1a+.cache_client._ListConcatenateFrontResponse\"\x00\x12n\n\x13ListConcatenateBack\x12).cache_client._ListConcatenateBackRequest\x1a*.cache_client._ListConcatenateBackResponse\"\x00\x12S\n\nListRetain\x12 .cache_client._ListRetainRequest\x1a!.cache_client._ListRetainResponse\"\x00\x12Y\n\x0cSortedSetPut\x12\".cache_client._SortedSetPutRequest\x1a#.cache_client._SortedSetPutResponse\"\x00\x12_\n\x0eSortedSetFetch\x12$.cache_client._SortedSetFetchRequest\x1a%.cache_client._SortedSetFetchResponse\"\x00\x12h\n\x11SortedSetGetScore\x12\'.cache_client._SortedSetGetScoreRequest\x1a(.cache_client._SortedSetGetScoreResponse\"\x00\x12\x62\n\x0fSortedSetRemove\x12%.cache_client._SortedSetRemoveRequest\x1a&.cache_client._SortedSetRemoveResponse\"\x00\x12k\n\x12SortedSetIncrement\x12(.cache_client._SortedSetIncrementRequest\x1a).cache_client._SortedSetIncrementResponse\"\x00\x12\x65\n\x10SortedSetGetRank\x12&.cache_client._SortedSetGetRankRequest\x1a\'.cache_client._SortedSetGetRankResponse\"\x00\x12\x62\n\x0fSortedSetLength\x12%.cache_client._SortedSetLengthRequest\x1a&.cache_client._SortedSetLengthResponse\"\x00\x12w\n\x16SortedSetLengthByScore\x12,.cache_client._SortedSetLengthByScoreRequest\x1a-.cache_client._SortedSetLengthByScoreResponse\"\x00\x42\x64\n\x11grpc.cache_clientP\x01Z0github.com/momentohq/client-sdk-go;client_sdk_go\xaa\x02\x1aMomento.Protos.CacheClientb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cacheclient_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021grpc.cache_clientP\001Z0github.com/momentohq/client-sdk-go;client_sdk_go\252\002\032Momento.Protos.CacheClient'
  _SCS.methods_by_name['SetIfNotExists']._options = None
  _SCS.methods_by_name['SetIfNotExists']._serialized_options = b'\210\002\001'
  _ECACHERESULT._serialized_start=12922
  _ECACHERESULT._serialized_end=12982
  __GETREQUEST._serialized_start=49
  __GETREQUEST._serialized_end=81
  __GETRESPONSE._serialized_start=83
  __GETRESPONSE._serialized_end=178
  __GETBATCHREQUEST._serialized_start=180
  __GETBATCHREQUEST._serialized_end=240
  __DELETEREQUEST._serialized_start=242
  __DELETEREQUEST._serialized_end=277
  __DELETERESPONSE._serialized_start=279
  __DELETERESPONSE._serialized_end=296
  __SETREQUEST._serialized_start=298
  __SETREQUEST._serialized_end=376
  __SETRESPONSE._serialized_start=378
  __SETRESPONSE._serialized_end=453
  __SETBATCHREQUEST._serialized_start=455
  __SETBATCHREQUEST._serialized_end=515
  __SETIFREQUEST._serialized_start=518
  __SETIFREQUEST._serialized_end=863
  __SETIFRESPONSE._serialized_start=866
  __SETIFRESPONSE._serialized_end=1036
  __SETIFRESPONSE__STORED._serialized_start=1003
  __SETIFRESPONSE__STORED._serialized_end=1012
  __SETIFRESPONSE__NOTSTORED._serialized_start=1014
  __SETIFRESPONSE__NOTSTORED._serialized_end=1026
  __SETIFNOTEXISTSREQUEST._serialized_start=1038
  __SETIFNOTEXISTSREQUEST._serialized_end=1127
  __SETIFNOTEXISTSRESPONSE._serialized_start=1130
  __SETIFNOTEXISTSRESPONSE._serialized_end=1327
  __SETIFNOTEXISTSRESPONSE__STORED._serialized_start=1003
  __SETIFNOTEXISTSRESPONSE__STORED._serialized_end=1012
  __SETIFNOTEXISTSRESPONSE__NOTSTORED._serialized_start=1014
  __SETIFNOTEXISTSRESPONSE__NOTSTORED._serialized_end=1026
  __KEYSEXISTREQUEST._serialized_start=1329
  __KEYSEXISTREQUEST._serialized_end=1368
  __KEYSEXISTRESPONSE._serialized_start=1370
  __KEYSEXISTRESPONSE._serialized_end=1406
  __INCREMENTREQUEST._serialized_start=1408
  __INCREMENTREQUEST._serialized_end=1488
  __INCREMENTRESPONSE._serialized_start=1490
  __INCREMENTRESPONSE._serialized_end=1525
  __UPDATETTLREQUEST._serialized_start=1528
  __UPDATETTLREQUEST._serialized_end=1689
  __UPDATETTLRESPONSE._serialized_start=1692
  __UPDATETTLRESPONSE._serialized_end=1930
  __UPDATETTLRESPONSE__SET._serialized_start=1891
  __UPDATETTLRESPONSE__SET._serialized_end=1897
  __UPDATETTLRESPONSE__NOTSET._serialized_start=1899
  __UPDATETTLRESPONSE__NOTSET._serialized_end=1908
  __UPDATETTLRESPONSE__MISSING._serialized_start=1910
  __UPDATETTLRESPONSE__MISSING._serialized_end=1920
  __ITEMGETTTLREQUEST._serialized_start=1932
  __ITEMGETTTLREQUEST._serialized_end=1971
  __ITEMGETTTLRESPONSE._serialized_start=1974
  __ITEMGETTTLRESPONSE._serialized_end=2179
  __ITEMGETTTLRESPONSE__FOUND._serialized_start=2119
  __ITEMGETTTLRESPONSE__FOUND._serialized_end=2157
  __ITEMGETTTLRESPONSE__MISSING._serialized_start=1910
  __ITEMGETTTLRESPONSE__MISSING._serialized_end=1920
  __ITEMGETTYPEREQUEST._serialized_start=2181
  __ITEMGETTYPEREQUEST._serialized_end=2221
  __ITEMGETTYPERESPONSE._serialized_start=2224
  __ITEMGETTYPERESPONSE._serialized_end=2541
  __ITEMGETTYPERESPONSE__FOUND._serialized_start=2372
  __ITEMGETTYPERESPONSE__FOUND._serialized_end=2444
  __ITEMGETTYPERESPONSE__MISSING._serialized_start=1910
  __ITEMGETTYPERESPONSE__MISSING._serialized_end=1920
  __ITEMGETTYPERESPONSE_ITEMTYPE._serialized_start=2458
  __ITEMGETTYPERESPONSE_ITEMTYPE._serialized_end=2531
  __DICTIONARYGETREQUEST._serialized_start=2543
  __DICTIONARYGETREQUEST._serialized_end=2607
  __DICTIONARYGETRESPONSE._serialized_start=2610
  __DICTIONARYGETRESPONSE._serialized_end=2972
  __DICTIONARYGETRESPONSE__DICTIONARYGETRESPONSEPART._serialized_start=2764
  __DICTIONARYGETRESPONSE__DICTIONARYGETRESPONSEPART._serialized_end=2856
  __DICTIONARYGETRESPONSE__FOUND._serialized_start=2858
  __DICTIONARYGETRESPONSE__FOUND._serialized_end=2946
  __DICTIONARYGETRESPONSE__MISSING._serialized_start=1910
  __DICTIONARYGETRESPONSE__MISSING._serialized_end=1920
  __DICTIONARYFETCHREQUEST._serialized_start=2974
  __DICTIONARYFETCHREQUEST._serialized_end=3024
  __DICTIONARYFIELDVALUEPAIR._serialized_start=3026
  __DICTIONARYFIELDVALUEPAIR._serialized_end=3083
  __DICTIONARYFETCHRESPONSE._serialized_start=3086
  __DICTIONARYFETCHRESPONSE._serialized_end=3336
  __DICTIONARYFETCHRESPONSE__FOUND._serialized_start=3246
  __DICTIONARYFETCHRESPONSE__FOUND._serialized_end=3310
  __DICTIONARYFETCHRESPONSE__MISSING._serialized_start=1910
  __DICTIONARYFETCHRESPONSE__MISSING._serialized_end=1920
  __DICTIONARYSETREQUEST._serialized_start=3339
  __DICTIONARYSETREQUEST._serialized_end=3490
  __DICTIONARYSETRESPONSE._serialized_start=3492
  __DICTIONARYSETRESPONSE._serialized_end=3516
  __DICTIONARYINCREMENTREQUEST._serialized_start=3519
  __DICTIONARYINCREMENTREQUEST._serialized_end=3651
  __DICTIONARYINCREMENTRESPONSE._serialized_start=3653
  __DICTIONARYINCREMENTRESPONSE._serialized_end=3698
  __DICTIONARYDELETEREQUEST._serialized_start=3701
  __DICTIONARYDELETEREQUEST._serialized_end=3913
  __DICTIONARYDELETEREQUEST_SOME._serialized_start=3874
  __DICTIONARYDELETEREQUEST_SOME._serialized_end=3896
  __DICTIONARYDELETEREQUEST_ALL._serialized_start=3898
  __DICTIONARYDELETEREQUEST_ALL._serialized_end=3903
  __DICTIONARYDELETERESPONSE._serialized_start=3915
  __DICTIONARYDELETERESPONSE._serialized_end=3942
  __DICTIONARYLENGTHREQUEST._serialized_start=3944
  __DICTIONARYLENGTHREQUEST._serialized_end=3995
  __DICTIONARYLENGTHRESPONSE._serialized_start=3998
  __DICTIONARYLENGTHRESPONSE._serialized_end=4211
  __DICTIONARYLENGTHRESPONSE__FOUND._serialized_start=4161
  __DICTIONARYLENGTHRESPONSE__FOUND._serialized_end=4185
  __DICTIONARYLENGTHRESPONSE__MISSING._serialized_start=1910
  __DICTIONARYLENGTHRESPONSE__MISSING._serialized_end=1920
  __SETFETCHREQUEST._serialized_start=4213
  __SETFETCHREQUEST._serialized_end=4249
  __SETFETCHRESPONSE._serialized_start=4252
  __SETFETCHRESPONSE._serialized_end=4436
  __SETFETCHRESPONSE__FOUND._serialized_start=4391
  __SETFETCHRESPONSE__FOUND._serialized_end=4417
  __SETFETCHRESPONSE__MISSING._serialized_start=1910
  __SETFETCHRESPONSE__MISSING._serialized_end=1920
  __SETSAMPLEREQUEST._serialized_start=4438
  __SETSAMPLEREQUEST._serialized_end=4490
  __SETSAMPLERESPONSE._serialized_start=4493
  __SETSAMPLERESPONSE._serialized_end=4680
  __SETSAMPLERESPONSE__FOUND._serialized_start=4391
  __SETSAMPLERESPONSE__FOUND._serialized_end=4417
  __SETSAMPLERESPONSE__MISSING._serialized_start=1910
  __SETSAMPLERESPONSE__MISSING._serialized_end=1920
  __SETUNIONREQUEST._serialized_start=4682
  __SETUNIONREQUEST._serialized_end=4783
  __SETUNIONRESPONSE._serialized_start=4785
  __SETUNIONRESPONSE._serialized_end=4804
  __SETDIFFERENCEREQUEST._serialized_start=4807
  __SETDIFFERENCEREQUEST._serialized_end=5249
  __SETDIFFERENCEREQUEST__MINUEND._serialized_start=4986
  __SETDIFFERENCEREQUEST__MINUEND._serialized_end=5014
  __SETDIFFERENCEREQUEST__SUBTRAHEND._serialized_start=5017
  __SETDIFFERENCEREQUEST__SUBTRAHEND._serialized_end=5235
  __SETDIFFERENCEREQUEST__SUBTRAHEND__SET._serialized_start=5180
  __SETDIFFERENCEREQUEST__SUBTRAHEND__SET._serialized_end=5204
  __SETDIFFERENCEREQUEST__SUBTRAHEND__IDENTITY._serialized_start=5206
  __SETDIFFERENCEREQUEST__SUBTRAHEND__IDENTITY._serialized_end=5217
  __SETDIFFERENCERESPONSE._serialized_start=5252
  __SETDIFFERENCERESPONSE._serialized_end=5433
  __SETDIFFERENCERESPONSE__FOUND._serialized_start=2119
  __SETDIFFERENCERESPONSE__FOUND._serialized_end=2127
  __SETDIFFERENCERESPONSE__MISSING._serialized_start=1910
  __SETDIFFERENCERESPONSE__MISSING._serialized_end=1920
  __SETCONTAINSREQUEST._serialized_start=5435
  __SETCONTAINSREQUEST._serialized_end=5492
  __SETCONTAINSRESPONSE._serialized_start=5495
  __SETCONTAINSRESPONSE._serialized_end=5688
  __SETCONTAINSRESPONSE__FOUND._serialized_start=5643
  __SETCONTAINSRESPONSE__FOUND._serialized_end=5669
  __SETCONTAINSRESPONSE__MISSING._serialized_start=1910
  __SETCONTAINSRESPONSE__MISSING._serialized_end=1920
  __SETLENGTHREQUEST._serialized_start=5690
  __SETLENGTHREQUEST._serialized_end=5727
  __SETLENGTHRESPONSE._serialized_start=5730
  __SETLENGTHRESPONSE._serialized_end=5915
  __SETLENGTHRESPONSE__FOUND._serialized_start=4161
  __SETLENGTHRESPONSE__FOUND._serialized_end=4185
  __SETLENGTHRESPONSE__MISSING._serialized_start=1910
  __SETLENGTHRESPONSE__MISSING._serialized_end=1920
  __SETPOPREQUEST._serialized_start=5917
  __SETPOPREQUEST._serialized_end=5966
  __SETPOPRESPONSE._serialized_start=5969
  __SETPOPRESPONSE._serialized_end=6147
  __SETPOPRESPONSE__FOUND._serialized_start=4391
  __SETPOPRESPONSE__FOUND._serialized_end=4417
  __SETPOPRESPONSE__MISSING._serialized_start=1910
  __SETPOPRESPONSE__MISSING._serialized_end=1920
  __LISTCONCATENATEFRONTREQUEST._serialized_start=6150
  __LISTCONCATENATEFRONTREQUEST._serialized_end=6293
  __LISTCONCATENATEFRONTRESPONSE._serialized_start=6295
  __LISTCONCATENATEFRONTRESPONSE._serialized_end=6347
  __LISTCONCATENATEBACKREQUEST._serialized_start=6350
  __LISTCONCATENATEBACKREQUEST._serialized_end=6493
  __LISTCONCATENATEBACKRESPONSE._serialized_start=6495
  __LISTCONCATENATEBACKRESPONSE._serialized_end=6546
  __LISTPUSHFRONTREQUEST._serialized_start=6549
  __LISTPUSHFRONTREQUEST._serialized_end=6684
  __LISTPUSHFRONTRESPONSE._serialized_start=6686
  __LISTPUSHFRONTRESPONSE._serialized_end=6731
  __LISTPUSHBACKREQUEST._serialized_start=6734
  __LISTPUSHBACKREQUEST._serialized_end=6869
  __LISTPUSHBACKRESPONSE._serialized_start=6871
  __LISTPUSHBACKRESPONSE._serialized_end=6915
  __LISTPOPFRONTREQUEST._serialized_start=6917
  __LISTPOPFRONTREQUEST._serialized_end=6958
  __LISTPOPFRONTRESPONSE._serialized_start=6961
  __LISTPOPFRONTRESPONSE._serialized_end=7176
  __LISTPOPFRONTRESPONSE__FOUND._serialized_start=7112
  __LISTPOPFRONTRESPONSE__FOUND._serialized_end=7156
  __LISTPOPFRONTRESPONSE__MISSING._serialized_start=1910
  __LISTPOPFRONTRESPONSE__MISSING._serialized_end=1920
  __LISTPOPBACKREQUEST._serialized_start=7178
  __LISTPOPBACKREQUEST._serialized_end=7218
  __LISTPOPBACKRESPONSE._serialized_start=7221
  __LISTPOPBACKRESPONSE._serialized_end=7432
  __LISTPOPBACKRESPONSE__FOUND._serialized_start=7369
  __LISTPOPBACKRESPONSE__FOUND._serialized_end=7412
  __LISTPOPBACKRESPONSE__MISSING._serialized_start=1910
  __LISTPOPBACKRESPONSE__MISSING._serialized_end=1920
  __LISTRANGE._serialized_start=7434
  __LISTRANGE._serialized_end=7482
  __LISTERASEREQUEST._serialized_start=7485
  __LISTERASEREQUEST._serialized_end=7711
  __LISTERASEREQUEST__ALL._serialized_start=7639
  __LISTERASEREQUEST__ALL._serialized_end=7645
  __LISTERASEREQUEST__LISTRANGES._serialized_start=7647
  __LISTERASEREQUEST__LISTRANGES._serialized_end=7702
  __LISTERASERESPONSE._serialized_start=7714
  __LISTERASERESPONSE._serialized_end=7905
  __LISTERASERESPONSE__FOUND._serialized_start=7856
  __LISTERASERESPONSE__FOUND._serialized_end=7885
  __LISTERASERESPONSE__MISSING._serialized_start=1910
  __LISTERASERESPONSE__MISSING._serialized_end=1920
  __LISTREMOVEREQUEST._serialized_start=7907
  __LISTREMOVEREQUEST._serialized_end=7991
  __LISTREMOVERESPONSE._serialized_start=7994
  __LISTREMOVERESPONSE._serialized_end=8188
  __LISTREMOVERESPONSE__FOUND._serialized_start=7856
  __LISTREMOVERESPONSE__FOUND._serialized_end=7885
  __LISTREMOVERESPONSE__MISSING._serialized_start=1910
  __LISTREMOVERESPONSE__MISSING._serialized_end=1920
  __LISTFETCHREQUEST._serialized_start=8191
  __LISTFETCHREQUEST._serialized_end=8401
  __LISTRETAINREQUEST._serialized_start=8404
  __LISTRETAINREQUEST._serialized_end=8662
  __LISTRETAINRESPONSE._serialized_start=8665
  __LISTRETAINRESPONSE._serialized_end=8859
  __LISTRETAINRESPONSE__FOUND._serialized_start=7856
  __LISTRETAINRESPONSE__FOUND._serialized_end=7885
  __LISTRETAINRESPONSE__MISSING._serialized_start=1910
  __LISTRETAINRESPONSE__MISSING._serialized_end=1920
  __LISTFETCHRESPONSE._serialized_start=8862
  __LISTFETCHRESPONSE._serialized_end=9048
  __LISTFETCHRESPONSE__FOUND._serialized_start=9004
  __LISTFETCHRESPONSE__FOUND._serialized_end=9028
  __LISTFETCHRESPONSE__MISSING._serialized_start=1910
  __LISTFETCHRESPONSE__MISSING._serialized_end=1920
  __LISTLENGTHREQUEST._serialized_start=9050
  __LISTLENGTHREQUEST._serialized_end=9089
  __LISTLENGTHRESPONSE._serialized_start=9092
  __LISTLENGTHRESPONSE._serialized_end=9281
  __LISTLENGTHRESPONSE__FOUND._serialized_start=4161
  __LISTLENGTHRESPONSE__FOUND._serialized_end=4185
  __LISTLENGTHRESPONSE__MISSING._serialized_start=1910
  __LISTLENGTHRESPONSE__MISSING._serialized_end=1920
  __SORTEDSETELEMENT._serialized_start=9283
  __SORTEDSETELEMENT._serialized_end=9332
  __SORTEDSETPUTREQUEST._serialized_start=9335
  __SORTEDSETPUTREQUEST._serialized_end=9473
  __SORTEDSETPUTRESPONSE._serialized_start=9475
  __SORTEDSETPUTRESPONSE._serialized_end=9498
  __SORTEDSETFETCHREQUEST._serialized_start=9501
  __SORTEDSETFETCHREQUEST._serialized_end=10333
  __SORTEDSETFETCHREQUEST__BYINDEX._serialized_start=9760
  __SORTEDSETFETCHREQUEST__BYINDEX._serialized_end=9942
  __SORTEDSETFETCHREQUEST__BYSCORE._serialized_start=9945
  __SORTEDSETFETCHREQUEST__BYSCORE._serialized_end=10284
  __SORTEDSETFETCHREQUEST__BYSCORE__SCORE._serialized_start=10228
  __SORTEDSETFETCHREQUEST__BYSCORE__SCORE._serialized_end=10270
  __SORTEDSETFETCHREQUEST_ORDER._serialized_start=10286
  __SORTEDSETFETCHREQUEST_ORDER._serialized_end=10324
  __SORTEDSETFETCHRESPONSE._serialized_start=10336
  __SORTEDSETFETCHRESPONSE._serialized_end=10805
  __SORTEDSETFETCHRESPONSE__FOUND._serialized_start=10494
  __SORTEDSETFETCHRESPONSE__FOUND._serialized_end=10779
  __SORTEDSETFETCHRESPONSE__FOUND__VALUESWITHSCORES._serialized_start=10670
  __SORTEDSETFETCHRESPONSE__FOUND__VALUESWITHSCORES._serialized_end=10740
  __SORTEDSETFETCHRESPONSE__FOUND__VALUES._serialized_start=10742
  __SORTEDSETFETCHRESPONSE__FOUND__VALUES._serialized_end=10767
  __SORTEDSETFETCHRESPONSE__MISSING._serialized_start=1910
  __SORTEDSETFETCHRESPONSE__MISSING._serialized_end=1920
  __SORTEDSETGETSCOREREQUEST._serialized_start=10807
  __SORTEDSETGETSCOREREQUEST._serialized_end=10868
  __SORTEDSETGETSCORERESPONSE._serialized_start=10871
  __SORTEDSETGETSCORERESPONSE._serialized_end=11291
  __SORTEDSETGETSCORERESPONSE__SORTEDSETGETSCORERESPONSEPART._serialized_start=11055
  __SORTEDSETGETSCORERESPONSE__SORTEDSETGETSCORERESPONSEPART._serialized_end=11146
  __SORTEDSETGETSCORERESPONSE__SORTEDSETFOUND._serialized_start=11148
  __SORTEDSETGETSCORERESPONSE__SORTEDSETFOUND._serialized_end=11256
  __SORTEDSETGETSCORERESPONSE__SORTEDSETMISSING._serialized_start=11258
  __SORTEDSETGETSCORERESPONSE__SORTEDSETMISSING._serialized_end=11277
  __SORTEDSETREMOVEREQUEST._serialized_start=11294
  __SORTEDSETREMOVEREQUEST._serialized_end=11509
  __SORTEDSETREMOVEREQUEST__ALL._serialized_start=7639
  __SORTEDSETREMOVEREQUEST__ALL._serialized_end=7645
  __SORTEDSETREMOVEREQUEST__SOME._serialized_start=11467
  __SORTEDSETREMOVEREQUEST__SOME._serialized_end=11490
  __SORTEDSETREMOVERESPONSE._serialized_start=11511
  __SORTEDSETREMOVERESPONSE._serialized_end=11537
  __SORTEDSETINCREMENTREQUEST._serialized_start=11539
  __SORTEDSETINCREMENTREQUEST._serialized_end=11663
  __SORTEDSETINCREMENTRESPONSE._serialized_start=11665
  __SORTEDSETINCREMENTRESPONSE._serialized_end=11709
  __SORTEDSETGETRANKREQUEST._serialized_start=11712
  __SORTEDSETGETRANKREQUEST._serialized_end=11872
  __SORTEDSETGETRANKREQUEST_ORDER._serialized_start=10286
  __SORTEDSETGETRANKREQUEST_ORDER._serialized_end=10324
  __SORTEDSETGETRANKRESPONSE._serialized_start=11875
  __SORTEDSETGETRANKRESPONSE._serialized_end=12171
  __SORTEDSETGETRANKRESPONSE__RANKRESPONSEPART._serialized_start=12065
  __SORTEDSETGETRANKRESPONSE__RANKRESPONSEPART._serialized_end=12142
  __SORTEDSETGETRANKRESPONSE__SORTEDSETMISSING._serialized_start=11258
  __SORTEDSETGETRANKRESPONSE__SORTEDSETMISSING._serialized_end=11277
  __SORTEDSETLENGTHREQUEST._serialized_start=12173
  __SORTEDSETLENGTHREQUEST._serialized_end=12216
  __SORTEDSETLENGTHRESPONSE._serialized_start=12219
  __SORTEDSETLENGTHRESPONSE._serialized_end=12429
  __SORTEDSETLENGTHRESPONSE__FOUND._serialized_start=4161
  __SORTEDSETLENGTHRESPONSE__FOUND._serialized_end=4185
  __SORTEDSETLENGTHRESPONSE__MISSING._serialized_start=1910
  __SORTEDSETLENGTHRESPONSE__MISSING._serialized_end=1920
  __SORTEDSETLENGTHBYSCOREREQUEST._serialized_start=12432
  __SORTEDSETLENGTHBYSCOREREQUEST._serialized_end=12686
  __SORTEDSETLENGTHBYSCORERESPONSE._serialized_start=12689
  __SORTEDSETLENGTHBYSCORERESPONSE._serialized_end=12920
  __SORTEDSETLENGTHBYSCORERESPONSE__FOUND._serialized_start=4161
  __SORTEDSETLENGTHBYSCORERESPONSE__FOUND._serialized_end=4185
  __SORTEDSETLENGTHBYSCORERESPONSE__MISSING._serialized_start=1910
  __SORTEDSETLENGTHBYSCORERESPONSE__MISSING._serialized_end=1920
  _SCS._serialized_start=12985
  _SCS._serialized_end=16952
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vectorindex.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11vectorindex.proto\x12\x0bvectorindex\"c\n\x05_Item\x12\n\n\x02id\x18\x01 \x01(\t\x12$\n\x06vector\x18\x02 \x01(\x0b\x32\x14.vectorindex._Vector\x12(\n\x08metadata\x18\x03 \x03(\x0b\x32\x16.vectorindex._Metadata\"P\n\x17_UpsertItemBatchRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12!\n\x05items\x18\x02 \x03(\x0b\x32\x12.vectorindex._Item\"1\n\x18_UpsertItemBatchResponse\x12\x15\n\rerror_indices\x18\x01 \x03(\r\"j\n\x17_DeleteItemBatchRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x0b\n\x03ids\x18\x02 \x03(\t\x12.\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x1e.vectorindex._FilterExpression\"\x1a\n\x18_DeleteItemBatchResponse\"\x1b\n\x07_Vector\x12\x10\n\x08\x65lements\x18\x01 \x03(\x02\"\xef\x01\n\t_Metadata\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x16\n\x0cstring_value\x18\x02 \x01(\tH\x00\x12\x17\n\rinteger_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x04 \x01(\x01H\x00\x12\x17\n\rboolean_value\x18\x05 \x01(\x08H\x00\x12\x46\n\x15list_of_strings_value\x18\x06 \x01(\x0b\x32%.vectorindex._Metadata._ListOfStringsH\x00\x1a \n\x0e_ListOfStrings\x12\x0e\n\x06values\x18\x01 \x03(\tB\x07\n\x05value\"\x9f\x01\n\x10_MetadataRequest\x12\x32\n\x04some\x18\x02 \x01(\x0b\x32\".vectorindex._MetadataRequest.SomeH\x00\x12\x30\n\x03\x61ll\x18\x03 \x01(\x0b\x32!.vectorindex._MetadataRequest.AllH\x00\x1a\x16\n\x04Some\x12\x0e\n\x06\x66ields\x18\x01 \x03(\t\x1a\x05\n\x03\x41llB\x06\n\x04kind\"\x85\x01\n\x0e_AndExpression\x12\x38\n\x10\x66irst_expression\x18\x01 \x01(\x0b\x32\x1e.vectorindex._FilterExpression\x12\x39\n\x11second_expression\x18\x02 \x01(\x0b\x32\x1e.vectorindex._FilterExpression\"\x84\x01\n\r_OrExpression\x12\x38\n\x10\x66irst_expression\x18\x01 \x01(\x0b\x32\x1e.vectorindex._FilterExpression\x12\x39\n\x11second_expression\x18\x02 \x01(\x0b\x32\x1e.vectorindex._FilterExpression\"N\n\x0e_NotExpression\x12<\n\x14\x65xpression_to_negate\x18\x01 \x01(\x0b\x32\x1e.vectorindex._FilterExpression\"\x8c\x01\n\x11_EqualsExpression\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x16\n\x0cstring_value\x18\x02 \x01(\tH\x00\x12\x17\n\rinteger_value\x18\x03 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x04 \x01(\x02H\x00\x12\x17\n\rboolean_value\x18\x05 \x01(\x08H\x00\x42\x07\n\x05value\"`\n\x16_GreaterThanExpression\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x17\n\rinteger_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x02H\x00\x42\x07\n\x05value\"g\n\x1d_GreaterThanOrEqualExpression\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x17\n\rinteger_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x02H\x00\x42\x07\n\x05value\"]\n\x13_LessThanExpression\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x17\n\rinteger_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x02H\x00\x42\x07\n\x05value\"d\n\x1a_LessThanOrEqualExpression\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x17\n\rinteger_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x02H\x00\x42\x07\n\x05value\"I\n\x17_ListContainsExpression\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x16\n\x0cstring_value\x18\x02 \x01(\tH\x00\x42\x07\n\x05value\"!\n\x12_IdInSetExpression\x12\x0b\n\x03ids\x18\x01 \x03(\t\"\xc0\x05\n\x11_FilterExpression\x12;\n\x11\x65quals_expression\x18\x01 \x01(\x0b\x32\x1e.vectorindex._EqualsExpressionH\x00\x12\x35\n\x0e\x61nd_expression\x18\x02 \x01(\x0b\x32\x1b.vectorindex._AndExpressionH\x00\x12\x33\n\ror_expression\x18\x03 \x01(\x0b\x32\x1a.vectorindex._OrExpressionH\x00\x12\x35\n\x0enot_expression\x18\x04 \x01(\x0b\x32\x1b.vectorindex._NotExpressionH\x00\x12\x46\n\x17greater_than_expression\x18\x05 \x01(\x0b\x32#.vectorindex._GreaterThanExpressionH\x00\x12V\n greater_than_or_equal_expression\x18\x06 \x01(\x0b\x32*.vectorindex._GreaterThanOrEqualExpressionH\x00\x12@\n\x14less_than_expression\x18\x07 \x01(\x0b\x32 .vectorindex._LessThanExpressionH\x00\x12P\n\x1dless_than_or_equal_expression\x18\x08 \x01(\x0b\x32\'.vectorindex._LessThanOrEqualExpressionH\x00\x12H\n\x18list_contains_expression\x18\t \x01(\x0b\x32$.vectorindex._ListContainsExpressionH\x00\x12?\n\x14id_in_set_expression\x18\n \x01(\x0b\x32\x1f.vectorindex._IdInSetExpressionH\x00\x42\x0c\n\nexpression\"\x13\n\x11_NoScoreThreshold\"\xad\x02\n\x0e_SearchRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\r\n\x05top_k\x18\x02 \x01(\r\x12*\n\x0cquery_vector\x18\x03 \x01(\x0b\x32\x14.vectorindex._Vector\x12\x36\n\x0fmetadata_fields\x18\x04 \x01(\x0b\x32\x1d.vectorindex._MetadataRequest\x12\x19\n\x0fscore_threshold\x18\x05 \x01(\x02H\x00\x12<\n\x12no_score_threshold\x18\x06 \x01(\x0b\x32\x1e.vectorindex._NoScoreThresholdH\x00\x12.\n\x06\x66ilter\x18\x07 \x01(\x0b\x32\x1e.vectorindex._FilterExpressionB\x0b\n\tthreshold\"\xbc\x02\n\x1d_SearchAndFetchVectorsRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\r\n\x05top_k\x18\x02 \x01(\r\x12*\n\x0cquery_vector\x18\x03 \x01(\x0b\x32\x14.vectorindex._Vector\x12\x36\n\x0fmetadata_fields\x18\x04 \x01(\x0b\x32\x1d.vectorindex._MetadataRequest\x12\x19\n\x0fscore_threshold\x18\x05 \x01(\x02H\x00\x12<\n\x12no_score_threshold\x18\x06 \x01(\x0b\x32\x1e.vectorindex._NoScoreThresholdH\x00\x12.\n\x06\x66ilter\x18\x07 \x01(\x0b\x32\x1e.vectorindex._FilterExpressionB\x0b\n\tthreshold\"Q\n\n_SearchHit\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x02\x12(\n\x08metadata\x18\x03 \x03(\x0b\x32\x16.vectorindex._Metadata\"\x86\x01\n\x19_SearchAndFetchVectorsHit\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x02\x12(\n\x08metadata\x18\x03 \x03(\x0b\x32\x16.vectorindex._Metadata\x12$\n\x06vector\x18\x04 \x01(\x0b\x32\x14.vectorindex._Vector\"8\n\x0f_SearchResponse\x12%\n\x04hits\x18\x01 \x03(\x0b\x32\x17.vectorindex._SearchHit\"V\n\x1e_SearchAndFetchVectorsResponse\x12\x34\n\x04hits\x18\x01 \x03(\x0b\x32&.vectorindex._SearchAndFetchVectorsHit\"\xa7\x01\n\x1c_GetItemMetadataBatchRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x0b\n\x03ids\x18\x02 \x03(\t\x12\x36\n\x0fmetadata_fields\x18\x03 \x01(\x0b\x32\x1d.vectorindex._MetadataRequest\x12.\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\x1e.vectorindex._FilterExpression\"\x92\x02\n\x15_ItemMetadataResponse\x12\x38\n\x04miss\x18\x01 \x01(\x0b\x32(.vectorindex._ItemMetadataResponse._MissH\x00\x12\x36\n\x03hit\x18\x02 \x01(\x0b\x32\'.vectorindex._ItemMetadataResponse._HitH\x00\x12\n\n\x02id\x18\x03 \x01(\t\x12(\n\x08metadata\x18\x04 \x03(\x0b\x32\x16.vectorindex._Metadata\x1a\x07\n\x05_Miss\x1a<\n\x04_Hit\x12\n\n\x02id\x18\x01 \x01(\t\x12(\n\x08metadata\x18\x02 \x03(\x0b\x32\x16.vectorindex._MetadataB\n\n\x08response\"c\n\x1d_GetItemMetadataBatchResponse\x12\x42\n\x16item_metadata_response\x18\x01 \x03(\x0b\x32\".vectorindex._ItemMetadataResponse\"\x9f\x01\n\x14_GetItemBatchRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x0b\n\x03ids\x18\x02 \x03(\t\x12\x36\n\x0fmetadata_fields\x18\x03 \x01(\x0b\x32\x1d.vectorindex._MetadataRequest\x12.\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\x1e.vectorindex._FilterExpression\"\xc6\x02\n\r_ItemResponse\x12\x30\n\x04miss\x18\x01 \x01(\x0b\x32 .vectorindex._ItemResponse._MissH\x00\x12.\n\x03hit\x18\x02 \x01(\x0b\x32\x1f.vectorindex._ItemResponse._HitH\x00\x12\n\n\x02id\x18\x03 \x01(\t\x12$\n\x06vector\x18\x04 \x01(\x0b\x32\x14.vectorindex._Vector\x12(\n\x08metadata\x18\x05 \x03(\x0b\x32\x16.vectorindex._Metadata\x1a\x07\n\x05_Miss\x1a\x62\n\x04_Hit\x12\n\n\x02id\x18\x01 \x01(\t\x12$\n\x06vector\x18\x02 \x01(\x0b\x32\x14.vectorindex._Vector\x12(\n\x08metadata\x18\x03 \x03(\x0b\x32\x16.vectorindex._MetadataB\n\n\x08response\"J\n\x15_GetItemBatchResponse\x12\x31\n\ritem_response\x18\x01 \x03(\x0b\x32\x1a.vectorindex._ItemResponse\"m\n\x12_CountItemsRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x32\n\x03\x61ll\x18\x02 \x01(\x0b\x32#.vectorindex._CountItemsRequest.AllH\x00\x1a\x05\n\x03\x41llB\x08\n\x06\x66ilter\")\n\x13_CountItemsResponse\x12\x12\n\nitem_count\x18\x01 \x01(\x04\x32\xa9\x05\n\x0bVectorIndex\x12`\n\x0fUpsertItemBatch\x12$.vectorindex._UpsertItemBatchRequest\x1a%.vectorindex._UpsertItemBatchResponse\"\x00\x12`\n\x0f\x44\x65leteItemBatch\x12$.vectorindex._DeleteItemBatchRequest\x1a%.vectorindex._DeleteItemBatchResponse\"\x00\x12\x45\n\x06Search\x12\x1b.vectorindex._SearchRequest\x1a\x1c.vectorindex._SearchResponse\"\x00\x12r\n\x15SearchAndFetchVectors\x12*.vectorindex._SearchAndFetchVectorsRequest\x1a+.vectorindex._SearchAndFetchVectorsResponse\"\x00\x12o\n\x14GetItemMetadataBatch\x12).vectorindex._GetItemMetadataBatchRequest\x1a*.vectorindex._GetItemMetadataBatchResponse\"\x00\x12W\n\x0cGetItemBatch\x12!.vectorindex._GetItemBatchRequest\x1a\".vectorindex._GetItemBatchResponse\"\x00\x12Q\n\nCountItems\x12\x1f.vectorindex._CountItemsRequest\x1a .vectorindex._CountItemsResponse\"\x00\x42\x63\n\x10grpc.vectorindexP\x01Z0github.com/momentohq/client-sdk-go;client_sdk_go\xaa\x02\x1aMomento.Protos.VectorIndexb\x06proto3')



__ITEM = DESCRIPTOR.message_types_by_name['_Item']
__UPSERTITEMBATCHREQUEST = DESCRIPTOR.message_types_by_name['_UpsertItemBatchRequest']
__UPSERTITEMBATCHRESPONSE = DESCRIPTOR.message_types_by_name['_UpsertItemBatchResponse']
__DELETEITEMBATCHREQUEST = DESCRIPTOR.message_types_by_name['_DeleteItemBatchRequest']
__DELETEITEMBATCHRESPONSE = DESCRIPTOR.message_types_by_name['_DeleteItemBatchResponse']
__VECTOR = DESCRIPTOR.message_types_by_name['_Vector']
__METADATA = DESCRIPTOR.message_types_by_name['_Metadata']
__METADATA__LISTOFSTRINGS = __METADATA.nested_types_by_name['_ListOfStrings']
__METADATAREQUEST = DESCRIPTOR.message_types_by_name['_MetadataRequest']
__METADATAREQUEST_SOME = __METADATAREQUEST.nested_types_by_name['Some']
__METADATAREQUEST_ALL = __METADATAREQUEST.nested_types_by_name['All']
__ANDEXPRESSION = DESCRIPTOR.message_types_by_name['_AndExpression']
__OREXPRESSION = DESCRIPTOR.message_types_by_name['_OrExpression']
__NOTEXPRESSION = DESCRIPTOR.message_types_by_name['_NotExpression']
__EQUALSEXPRESSION = DESCRIPTOR.message_types_by_name['_EqualsExpression']
__GREATERTHANEXPRESSION = DESCRIPTOR.message_types_by_name['_GreaterThanExpression']
__GREATERTHANOREQUALEXPRESSION = DESCRIPTOR.message_types_by_name['_GreaterThanOrEqualExpression']
__LESSTHANEXPRESSION = DESCRIPTOR.message_types_by_name['_LessThanExpression']
__LESSTHANOREQUALEXPRESSION = DESCRIPTOR.message_types_by_name['_LessThanOrEqualExpression']
__LISTCONTAINSEXPRESSION = DESCRIPTOR.message_types_by_name['_ListContainsExpression']
__IDINSETEXPRESSION = DESCRIPTOR.message_types_by_name['_IdInSetExpression']
__FILTEREXPRESSION = DESCRIPTOR.message_types_by_name['_FilterExpression']
__NOSCORETHRESHOLD = DESCRIPTOR.message_types_by_name['_NoScoreThreshold']
__SEARCHREQUEST = DESCRIPTOR.message_types_by_name['_SearchRequest']
__SEARCHANDFETCHVECTORSREQUEST = DESCRIPTOR.message_types_by_name['_SearchAndFetchVectorsRequest']
__SEARCHHIT = DESCRIPTOR.message_types_by_name['_SearchHit']
__SEARCHANDFETCHVECTORSHIT = DESCRIPTOR.message_types_by_name['_SearchAndFetchVectorsHit']
__SEARCHRESPONSE = DESCRIPTOR.message_types_by_name['_SearchResponse']
__SEARCHANDFETCHVECTORSRESPONSE = DESCRIPTOR.message_types_by_name['_SearchAndFetchVectorsResponse']
__GETITEMMETADATABATCHREQUEST = DESCRIPTOR.message_types_by_name['_GetItemMetadataBatchRequest']
__ITEMMETADATARESPONSE = DESCRIPTOR.message_types_by_name['_ItemMetadataResponse']
__ITEMMETADATARESPONSE__MISS = __ITEMMETADATARESPONSE.nested_types_by_name['_Miss']
__ITEMMETADATARESPONSE__HIT = __ITEMMETADATARESPONSE.nested_types_by_name['_Hit']
__GETITEMMETADATABATCHRESPONSE = DESCRIPTOR.message_types_by_name['_GetItemMetadataBatchResponse']
__GETITEMBATCHREQUEST = DESCRIPTOR.message_types_by_name['_GetItemBatchRequest']
__ITEMRESPONSE = DESCRIPTOR.message_types_by_name['_ItemResponse']
__ITEMRESPONSE__MISS = __ITEMRESPONSE.nested_types_by_name['_Miss']
__ITEMRESPONSE__HIT = __ITEMRESPONSE.nested_types_by_name['_Hit']
__GETITEMBATCHRESPONSE = DESCRIPTOR.message_types_by_name['_GetItemBatchResponse']
__COUNTITEMSREQUEST = DESCRIPTOR.message_types_by_name['_CountItemsRequest']
__COUNTITEMSREQUEST_ALL = __COUNTITEMSREQUEST.nested_types_by_name['All']
__COUNTITEMSRESPONSE = DESCRIPTOR.message_types_by_name['_CountItemsResponse']
_Item = _reflection.GeneratedProtocolMessageType('_Item', (_message.Message,), {
  'DESCRIPTOR' : __ITEM,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._Item)
  })
_sym_db.RegisterMessage(_Item)

_UpsertItemBatchRequest = _reflection.GeneratedProtocolMessageType('_UpsertItemBatchRequest', (_message.Message,), {
  'DESCRIPTOR' : __UPSERTITEMBATCHREQUEST,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._UpsertItemBatchRequest)
  })
_sym_db.RegisterMessage(_UpsertItemBatchRequest)

_UpsertItemBatchResponse = _reflection.GeneratedProtocolMessageType('_UpsertItemBatchResponse', (_message.Message,), {
  'DESCRIPTOR' : __UPSERTITEMBATCHRESPONSE,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._UpsertItemBatchResponse)
  })
_sym_db.RegisterMessage(_UpsertItemBatchResponse)

_DeleteItemBatchRequest = _reflection.GeneratedProtocolMessageType('_DeleteItemBatchRequest', (_message.Message,), {
  'DESCRIPTOR' : __DELETEITEMBATCHREQUEST,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._DeleteItemBatchRequest)
  })
_sym_db.RegisterMessage(_DeleteItemBatchRequest)

_DeleteItemBatchResponse = _reflection.GeneratedProtocolMessageType('_DeleteItemBatchResponse', (_message.Message,), {
  'DESCRIPTOR' : __DELETEITEMBATCHRESPONSE,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._DeleteItemBatchResponse)
  })
_sym_db.RegisterMessage(_DeleteItemBatchResponse)

_Vector = _reflection.GeneratedProtocolMessageType('_Vector', (_message.Message,), {
  'DESCRIPTOR' : __VECTOR,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._Vector)
  })
_sym_db.RegisterMessage(_Vector)

_Metadata = _reflection.GeneratedProtocolMessageType('_Metadata', (_message.Message,), {

  '_ListOfStrings' : _reflection.GeneratedProtocolMessageType('_ListOfStrings', (_message.Message,), {
    'DESCRIPTOR' : __METADATA__LISTOFSTRINGS,
    '__module__' : 'vectorindex_pb2'
    # @@protoc_insertion_point(class_scope:vectorindex._Metadata._ListOfStrings)
    })
  ,
  'DESCRIPTOR' : __METADATA,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._Metadata)
  })
_sym_db.RegisterMessage(_Metadata)
_sym_db.RegisterMessage(_Metadata._ListOfStrings)

_MetadataRequest = _reflection.GeneratedProtocolMessageType('_MetadataRequest', (_message.Message,), {

  'Some' : _reflection.GeneratedProtocolMessageType('Some', (_message.Message,), {
    'DESCRIPTOR' : __METADATAREQUEST_SOME,
    '__module__' : 'vectorindex_pb2'
    # @@protoc_insertion_point(class_scope:vectorindex._MetadataRequest.Some)
    })
  ,

  'All' : _reflection.GeneratedProtocolMessageType('All', (_message.Message,), {
    'DESCRIPTOR' : __METADATAREQUEST_ALL,
    '__module__' : 'vectorindex_pb2'
    # @@protoc_insertion_point(class_scope:vectorindex._MetadataRequest.All)
    })
  ,
  'DESCRIPTOR' : __METADATAREQUEST,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._MetadataRequest)
  })
_sym_db.RegisterMessage(_MetadataRequest)
_sym_db.RegisterMessage(_MetadataRequest.Some)
_sym_db.RegisterMessage(_MetadataRequest.All)

_AndExpression = _reflection.GeneratedProtocolMessageType('_AndExpression', (_message.Message,), {
  'DESCRIPTOR' : __ANDEXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._AndExpression)
  })
_sym_db.RegisterMessage(_AndExpression)

_OrExpression = _reflection.GeneratedProtocolMessageType('_OrExpression', (_message.Message,), {
  'DESCRIPTOR' : __OREXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._OrExpression)
  })
_sym_db.RegisterMessage(_OrExpression)

_NotExpression = _reflection.GeneratedProtocolMessageType('_NotExpression', (_message.Message,), {
  'DESCRIPTOR' : __NOTEXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._NotExpression)
  })
_sym_db.RegisterMessage(_NotExpression)

_EqualsExpression = _reflection.GeneratedProtocolMessageType('_EqualsExpression', (_message.Message,), {
  'DESCRIPTOR' : __EQUALSEXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._EqualsExpression)
  })
_sym_db.RegisterMessage(_EqualsExpression)

_GreaterThanExpression = _reflection.GeneratedProtocolMessageType('_GreaterThanExpression', (_message.Message,), {
  'DESCRIPTOR' : __GREATERTHANEXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._GreaterThanExpression)
  })
_sym_db.RegisterMessage(_GreaterThanExpression)

_GreaterThanOrEqualExpression = _reflection.GeneratedProtocolMessageType('_GreaterThanOrEqualExpression', (_message.Message,), {
  'DESCRIPTOR' : __GREATERTHANOREQUALEXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._GreaterThanOrEqualExpression)
  })
_sym_db.RegisterMessage(_GreaterThanOrEqualExpression)

_LessThanExpression = _reflection.GeneratedProtocolMessageType('_LessThanExpression', (_message.Message,), {
  'DESCRIPTOR' : __LESSTHANEXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._LessThanExpression)
  })
_sym_db.RegisterMessage(_LessThanExpression)

_LessThanOrEqualExpression = _reflection.GeneratedProtocolMessageType('_LessThanOrEqualExpression', (_message.Message,), {
  'DESCRIPTOR' : __LESSTHANOREQUALEXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._LessThanOrEqualExpression)
  })
_sym_db.RegisterMessage(_LessThanOrEqualExpression)

_ListContainsExpression = _reflection.GeneratedProtocolMessageType('_ListContainsExpression', (_message.Message,), {
  'DESCRIPTOR' : __LISTCONTAINSEXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._ListContainsExpression)
  })
_sym_db.RegisterMessage(_ListContainsExpression)

_IdInSetExpression = _reflection.GeneratedProtocolMessageType('_IdInSetExpression', (_message.Message,), {
  'DESCRIPTOR' : __IDINSETEXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._IdInSetExpression)
  })
_sym_db.RegisterMessage(_IdInSetExpression)

_FilterExpression = _reflection.GeneratedProtocolMessageType('_FilterExpression', (_message.Message,), {
  'DESCRIPTOR' : __FILTEREXPRESSION,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._FilterExpression)
  })
_sym_db.RegisterMessage(_FilterExpression)

_NoScoreThreshold = _reflection.GeneratedProtocolMessageType('_NoScoreThreshold', (_message.Message,), {
  'DESCRIPTOR' : __NOSCORETHRESHOLD,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._NoScoreThreshold)
  })
_sym_db.RegisterMessage(_NoScoreThreshold)

_SearchRequest = _reflection.GeneratedProtocolMessageType('_SearchRequest', (_message.Message,), {
  'DESCRIPTOR' : __SEARCHREQUEST,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._SearchRequest)
  })
_sym_db.RegisterMessage(_SearchRequest)

_SearchAndFetchVectorsRequest = _reflection.GeneratedProtocolMessageType('_SearchAndFetchVectorsRequest', (_message.Message,), {
  'DESCRIPTOR' : __SEARCHANDFETCHVECTORSREQUEST,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._SearchAndFetchVectorsRequest)
  })
_sym_db.RegisterMessage(_SearchAndFetchVectorsRequest)

_SearchHit = _reflection.GeneratedProtocolMessageType('_SearchHit', (_message.Message,), {
  'DESCRIPTOR' : __SEARCHHIT,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._SearchHit)
  })
_sym_db.RegisterMessage(_SearchHit)

_SearchAndFetchVectorsHit = _reflection.GeneratedProtocolMessageType('_SearchAndFetchVectorsHit', (_message.Message,), {
  'DESCRIPTOR' : __SEARCHANDFETCHVECTORSHIT,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._SearchAndFetchVectorsHit)
  })
_sym_db.RegisterMessage(_SearchAndFetchVectorsHit)

_SearchResponse = _reflection.GeneratedProtocolMessageType('_SearchResponse', (_message.Message,), {
  'DESCRIPTOR' : __SEARCHRESPONSE,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._SearchResponse)
  })
_sym_db.RegisterMessage(_SearchResponse)

_SearchAndFetchVectorsResponse = _reflection.GeneratedProtocolMessageType('_SearchAndFetchVectorsResponse', (_message.Message,), {
  'DESCRIPTOR' : __SEARCHANDFETCHVECTORSRESPONSE,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._SearchAndFetchVectorsResponse)
  })
_sym_db.RegisterMessage(_SearchAndFetchVectorsResponse)

_GetItemMetadataBatchRequest = _reflection.GeneratedProtocolMessageType('_GetItemMetadataBatchRequest', (_message.Message,), {
  'DESCRIPTOR' : __GETITEMMETADATABATCHREQUEST,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._GetItemMetadataBatchRequest)
  })
_sym_db.RegisterMessage(_GetItemMetadataBatchRequest)

_ItemMetadataResponse = _reflection.GeneratedProtocolMessageType('_ItemMetadataResponse', (_message.Message,), {

  '_Miss' : _reflection.GeneratedProtocolMessageType('_Miss', (_message.Message,), {
    'DESCRIPTOR' : __ITEMMETADATARESPONSE__MISS,
    '__module__' : 'vectorindex_pb2'
    # @@protoc_insertion_point(class_scope:vectorindex._ItemMetadataResponse._Miss)
    })
  ,

  '_Hit' : _reflection.GeneratedProtocolMessageType('_Hit', (_message.Message,), {
    'DESCRIPTOR' : __ITEMMETADATARESPONSE__HIT,
    '__module__' : 'vectorindex_pb2'
    # @@protoc_insertion_point(class_scope:vectorindex._ItemMetadataResponse._Hit)
    })
  ,
  'DESCRIPTOR' : __ITEMMETADATARESPONSE,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._ItemMetadataResponse)
  })
_sym_db.RegisterMessage(_ItemMetadataResponse)
_sym_db.RegisterMessage(_ItemMetadataResponse._Miss)
_sym_db.RegisterMessage(_ItemMetadataResponse._Hit)

_GetItemMetadataBatchResponse = _reflection.GeneratedProtocolMessageType('_GetItemMetadataBatchResponse', (_message.Message,), {
  'DESCRIPTOR' : __GETITEMMETADATABATCHRESPONSE,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._GetItemMetadataBatchResponse)
  })
_sym_db.RegisterMessage(_GetItemMetadataBatchResponse)

_GetItemBatchRequest = _reflection.GeneratedProtocolMessageType('_GetItemBatchRequest', (_message.Message,), {
  'DESCRIPTOR' : __GETITEMBATCHREQUEST,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._GetItemBatchRequest)
  })
_sym_db.RegisterMessage(_GetItemBatchRequest)

_ItemResponse = _reflection.GeneratedProtocolMessageType('_ItemResponse', (_message.Message,), {

  '_Miss' : _reflection.GeneratedProtocolMessageType('_Miss', (_message.Message,), {
    'DESCRIPTOR' : __ITEMRESPONSE__MISS,
    '__module__' : 'vectorindex_pb2'
    # @@protoc_insertion_point(class_scope:vectorindex._ItemResponse._Miss)
    })
  ,

  '_Hit' : _reflection.GeneratedProtocolMessageType('_Hit', (_message.Message,), {
    'DESCRIPTOR' : __ITEMRESPONSE__HIT,
    '__module__' : 'vectorindex_pb2'
    # @@protoc_insertion_point(class_scope:vectorindex._ItemResponse._Hit)
    })
  ,
  'DESCRIPTOR' : __ITEMRESPONSE,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._ItemResponse)
  })
_sym_db.RegisterMessage(_ItemResponse)
_sym_db.RegisterMessage(_ItemResponse._Miss)
_sym_db.RegisterMessage(_ItemResponse._Hit)

_GetItemBatchResponse = _reflection.GeneratedProtocolMessageType('_GetItemBatchResponse', (_message.Message,), {
  'DESCRIPTOR' : __GETITEMBATCHRESPONSE,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._GetItemBatchResponse)
  })
_sym_db.RegisterMessage(_GetItemBatchResponse)

_CountItemsRequest = _reflection.GeneratedProtocolMessageType('_CountItemsRequest', (_message.Message,), {

  'All' : _reflection.GeneratedProtocolMessageType('All', (_message.Message,), {
    'DESCRIPTOR' : __COUNTITEMSREQUEST_ALL,
    '__module__' : 'vectorindex_pb2'
    # @@protoc_insertion_point(class_scope:vectorindex._CountItemsRequest.All)
    })
  ,
  'DESCRIPTOR' : __COUNTITEMSREQUEST,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._CountItemsRequest)
  })
_sym_db.RegisterMessage(_CountItemsRequest)
_sym_db.RegisterMessage(_CountItemsRequest.All)

_CountItemsResponse = _reflection.GeneratedProtocolMessageType('_CountItemsResponse', (_message.Message,), {
  'DESCRIPTOR' : __COUNTITEMSRESPONSE,
  '__module__' : 'vectorindex_pb2'
  # @@protoc_insertion_point(class_scope:vectorindex._CountItemsResponse)
  })
_sym_db.RegisterMessage(_CountItemsResponse)

_VECTORINDEX = DESCRIPTOR.services_by_name['VectorIndex']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020grpc.vectorindexP\001Z0github.com/momentohq/client-sdk-go;client_sdk_go\252\002\032Momento.Protos.VectorIndex'
  __ITEM._serialized_start=34
  __ITEM._serialized_end=133
  __UPSERTITEMBATCHREQUEST._serialized_start=135
  __UPSERTITEMBATCHREQUEST._serialized_end=215
  __UPSERTITEMBATCHRESPONSE._serialized_start=217
  __UPSERTITEMBATCHRESPONSE._serialized_end=266
  __DELETEITEMBATCHREQUEST._serialized_start=268
  __DELETEITEMBATCHREQUEST._serialized_end=374
  __DELETEITEMBATCHRESPONSE._serialized_start=376
  __DELETEITEMBATCHRESPONSE._serialized_end=402
  __VECTOR._serialized_start=404
  __VECTOR._serialized_end=431
  __METADATA._serialized_start=434
  __METADATA._serialized_end=673
  __METADATA__LISTOFSTRINGS._serialized_start=632
  __METADATA__LISTOFSTRINGS._serialized_end=664
  __METADATAREQUEST._serialized_start=676
  __METADATAREQUEST._serialized_end=835
  __METADATAREQUEST_SOME._serialized_start=798
  __METADATAREQUEST_SOME._serialized_end=820
  __METADATAREQUEST_ALL._serialized_start=822
  __METADATAREQUEST_ALL._serialized_end=827
  __ANDEXPRESSION._serialized_start=838
  __ANDEXPRESSION._serialized_end=971
  __OREXPRESSION._serialized_start=974
  __OREXPRESSION._serialized_end=1106
  __NOTEXPRESSION._serialized_start=1108
  __NOTEXPRESSION._serialized_end=1186
  __EQUALSEXPRESSION._serialized_start=1189
  __EQUALSEXPRESSION._serialized_end=1329
  __GREATERTHANEXPRESSION._serialized_start=1331
  __GREATERTHANEXPRESSION._serialized_end=1427
  __GREATERTHANOREQUALEXPRESSION._serialized_start=1429
  __GREATERTHANOREQUALEXPRESSION._serialized_end=1532
  __LESSTHANEXPRESSION._serialized_start=1534
  __LESSTHANEXPRESSION._serialized_end=1627
  __LESSTHANOREQUALEXPRESSION._serialized_start=1629
  __LESSTHANOREQUALEXPRESSION._serialized_end=1729
  __LISTCONTAINSEXPRESSION._serialized_start=1731
  __LISTCONTAINSEXPRESSION._serialized_end=1804
  __IDINSETEXPRESSION._serialized_start=1806
  __IDINSETEXPRESSION._serialized_end=1839
  __FILTEREXPRESSION._serialized_start=1842
  __FILTEREXPRESSION._serialized_end=2546
  __NOSCORETHRESHOLD._serialized_start=2548
  __NOSCORETHRESHOLD._serialized_end=2567
  __SEARCHREQUEST._serialized_start=2570
  __SEARCHREQUEST._serialized_end=2871
  __SEARCHANDFETCHVECTORSREQUEST._serialized_start=2874
  __SEARCHANDFETCHVECTORSREQUEST._serialized_end=3190
  __SEARCHHIT._serialized_start=3192
  __SEARCHHIT._serialized_end=3273
  __SEARCHANDFETCHVECTORSHIT._serialized_start=3276
  __SEARCHANDFETCHVECTORSHIT._serialized_end=3410
  __SEARCHRESPONSE._serialized_start=3412
  __SEARCHRESPONSE._serialized_end=3468
  __SEARCHANDFETCHVECTORSRESPONSE._serialized_start=3470
  __SEARCHANDFETCHVECTORSRESPONSE._serialized_end=3556
  __GETITEMMETADATABATCHREQUEST._serialized_start=3559
  __GETITEMMETADATABATCHREQUEST._serialized_end=3726
  __ITEMMETADATARESPONSE._serialized_start=3729
  __ITEMMETADATARESPONSE._serialized_end=4003
  __ITEMMETADATARESPONSE__MISS._serialized_start=3922
  __ITEMMETADATARESPONSE__MISS._serialized_end=3929
  __ITEMMETADATARESPONSE__HIT._serialized_start=3931
  __ITEMMETADATARESPONSE__HIT._serialized_end=3991
  __GETITEMMETADATABATCHRESPONSE._serialized_start=4005
  __GETITEMMETADATABATCHRESPONSE._serialized_end=4104
  __GETITEMBATCHREQUEST._serialized_start=4107
  __GETITEMBATCHREQUEST._serialized_end=4266
  __ITEMRESPONSE._serialized_start=4269
  __ITEMRESPONSE._serialized_end=4595
  __ITEMRESPONSE__MISS._serialized_start=3922
  __ITEMRESPONSE__MISS._serialized_end=3929
  __ITEMRESPONSE__HIT._serialized_start=4485
  __ITEMRESPONSE__HIT._serialized_end=4583
  __GETITEMBATCHRESPONSE._serialized_start=4597
  __GETITEMBATCHRESPONSE._serialized_end=4671
  __COUNTITEMSREQUEST._serialized_start=4673
  __COUNTITEMSREQUEST._serialized_end=4782
  __COUNTITEMSREQUEST_ALL._serialized_start=822
  __COUNTITEMSREQUEST_ALL._serialized_end=827
  __COUNTITEMSRESPONSE._serialized_start=4784
  __COUNTITEMSRESPONSE._serialized_end=4825
  _VECTORINDEX._serialized_start=4828
  _VECTORINDEX._serialized_end=5509
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class _AndExpression(_message.Message):
    __slots__ = ["first_expression", "second_expression"]
    FIRST_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    SECOND_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    first_expression: _FilterExpression
    second_expression: _FilterExpression
    def __init__(self, first_expression: _Optional[_Union[_FilterExpression, _Mapping]] = ..., second_expression: _Optional[_Union[_FilterExpression, _Mapping]] = ...) -> None: ...

class _CountItemsRequest(_message.Message):
    __slots__ = ["all", "index_name"]
    class All(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    ALL_FIELD_NUMBER: _ClassVar[int]
    INDEX_NAME_FIELD_NUMBER: _ClassVar[int]
    all: _CountItemsRequest.All
    index_name: str
    def __init__(self, index_name: _Optional[str] = ..., all: _Optional[_Union[_CountItemsRequest.All, _Mapping]] = ...) -> None: ...

class _CountItemsResponse(_message.Message):
    __slots__ = ["item_count"]
    ITEM_COUNT_FIELD_NUMBER: _ClassVar[int]
    item_count: int
    def __init__(self, item_count: _Optional[int] = ...) -> None: ...

class _DeleteItemBatchRequest(_message.Message):
    __slots__ = ["filter", "ids", "index_name"]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    IDS_FIELD_NUMBER: _ClassVar[int]
    INDEX_NAME_FIELD_NUMBER: _ClassVar[int]
    filter: _FilterExpression
    ids: _containers.RepeatedScalarFieldContainer[str]
    index_name: str
    def __init__(self, index_name: _Optional[str] = ..., ids: _Optional[_Iterable[str]] = ..., filter: _Optional[_Union[_FilterExpression, _Mapping]] = ...) -> None: ...

class _DeleteItemBatchResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _EqualsExpression(_message.Message):
    __slots__ = ["boolean_value", "field", "float_value", "integer_value", "string_value"]
    BOOLEAN_VALUE_FIELD_NUMBER: _ClassVar[int]
    FIELD_FIELD_NUMBER: _ClassVar[int]
    FLOAT_VALUE_FIELD_NUMBER: _ClassVar[int]
    INTEGER_VALUE_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUE_FIELD_NUMBER: _ClassVar[int]
    boolean_value: bool
    field: str
    float_value: float
    integer_value: int
    string_value: str
    def __init__(self, field: _Optional[str] = ..., string_value: _Optional[str] = ..., integer_value: _Optional[int] = ..., float_value: _Optional[float] = ..., boolean_value: bool = ...) -> None: ...

class _FilterExpression(_message.Message):
    __slots__ = ["and_expression", "equals_expression", "greater_than_expression", "greater_than_or_equal_expression", "id_in_set_expression", "less_than_expression", "less_than_or_equal_expression", "list_contains_expression", "not_expression", "or_expression"]
    AND_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    EQUALS_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    GREATER_THAN_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    GREATER_THAN_OR_EQUAL_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    ID_IN_SET_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    LESS_THAN_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    LESS_THAN_OR_EQUAL_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    LIST_CONTAINS_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    NOT_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    OR_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    and_expression: _AndExpression
    equals_expression: _EqualsExpression
    greater_than_expression: _GreaterThanExpression
    greater_than_or_equal_expression: _GreaterThanOrEqualExpression
    id_in_set_expression: _IdInSetExpression
    less_than_expression: _LessThanExpression
    less_than_or_equal_expression: _LessThanOrEqualExpression
    list_contains_expression: _ListContainsExpression
    not_expression: _NotExpression
    or_expression: _OrExpression
    def __init__(self, equals_expression: _Optional[_Union[_EqualsExpression, _Mapping]] = ..., and_expression: _Optional[_Union[_AndExpression, _Mapping]] = ..., or_expression: _Optional[_Union[_OrExpression, _Mapping]] = ..., not_expression: _Optional[_Union[_NotExpression, _Mapping]] = ..., greater_than_expression: _Optional[_Union[_GreaterThanExpression, _Mapping]] = ..., greater_than_or_equal_expression: _Optional[_Union[_GreaterThanOrEqualExpression, _Mapping]] = ..., less_than_expression: _Optional[_Union[_LessThanExpression, _Mapping]] = ..., less_than_or_equal_expression: _Optional[_Union[_LessThanOrEqualExpression, _Mapping]] = ..., list_contains_expression: _Optional[_Union[_ListContainsExpression, _Mapping]] = ..., id_in_set_expression: _Optional[_Union[_IdInSetExpression, _Mapping]] = ...) -> None: ...

class _GetItemBatchRequest(_message.Message):
    __slots__ = ["filter", "ids", "index_name", "metadata_fields"]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    IDS_FIELD_NUMBER: _ClassVar[int]
    INDEX_NAME_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELDS_FIELD_NUMBER: _ClassVar[int]
    filter: _FilterExpression
    ids: _containers.RepeatedScalarFieldContainer[str]
    index_name: str
    metadata_fields: _MetadataRequest
    def __init__(self, index_name: _Optional[str] = ..., ids: _Optional[_Iterable[str]] = ..., metadata_fields: _Optional[_Union[_MetadataRequest, _Mapping]] = ..., filter: _Optional[_Union[_FilterExpression, _Mapping]] = ...) -> None: ...

class _GetItemBatchResponse(_message.Message):
    __slots__ = ["item_response"]
    ITEM_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    item_response: _containers.RepeatedCompositeFieldContainer[_ItemResponse]
    def __init__(self, item_response: _Optional[_Iterable[_Union[_ItemResponse, _Mapping]]] = ...) -> None: ...

class _GetItemMetadataBatchRequest(_message.Message):
    __slots__ = ["filter", "ids", "index_name", "metadata_fields"]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    IDS_FIELD_NUMBER: _ClassVar[int]
    INDEX_NAME_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELDS_FIELD_NUMBER: _ClassVar[int]
    filter: _FilterExpression
    ids: _containers.RepeatedScalarFieldContainer[str]
    index_name: str
    metadata_fields: _MetadataRequest
    def __init__(self, index_name: _Optional[str] = ..., ids: _Optional[_Iterable[str]] = ..., metadata_fields: _Optional[_Union[_MetadataRequest, _Mapping]] = ..., filter: _Optional[_Union[_FilterExpression, _Mapping]] = ...) -> None: ...

class _GetItemMetadataBatchResponse(_message.Message):
    __slots__ = ["item_metadata_response"]
    ITEM_METADATA_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    item_metadata_response: _containers.RepeatedCompositeFieldContainer[_ItemMetadataResponse]
    def __init__(self, item_metadata_response: _Optional[_Iterable[_Union[_ItemMetadataResponse, _Mapping]]] = ...) -> None: ...

class _GreaterThanExpression(_message.Message):
    __slots__ = ["field", "float_value", "integer_value"]
    FIELD_FIELD_NUMBER: _ClassVar[int]
    FLOAT_VALUE_FIELD_NUMBER: _ClassVar[int]
    INTEGER_VALUE_FIELD_NUMBER: _ClassVar[int]
    field: str
    float_value: float
    integer_value: int
    def __init__(self, field: _Optional[str] = ..., integer_value: _Optional[int] = ..., float_value: _Optional[float] = ...) -> None: ...

class _GreaterThanOrEqualExpression(_message.Message):
    __slots__ = ["field", "float_value", "integer_value"]
    FIELD_FIELD_NUMBER: _ClassVar[int]
    FLOAT_VALUE_FIELD_NUMBER: _ClassVar[int]
    INTEGER_VALUE_FIELD_NUMBER: _ClassVar[int]
    field: str
    float_value: float
    integer_value: int
    def __init__(self, field: _Optional[str] = ..., integer_value: _Optional[int] = ..., float_value: _Optional[float] = ...) -> None: ...

class _IdInSetExpression(_message.Message):
    __slots__ = ["ids"]
    IDS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ids: _Optional[_Iterable[str]] = ...) -> None: ...

class _Item(_message.Message):
    __slots__ = ["id", "metadata", "vector"]
    ID_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    VECTOR_FIELD_NUMBER: _ClassVar[int]
    id: str
    metadata: _containers.RepeatedCompositeFieldContainer[_Metadata]
    vector: _Vector
    def __init__(self, id: _Optional[str] = ..., vector: _Optional[_Union[_Vector, _Mapping]] = ..., metadata: _Optional[_Iterable[_Union[_Metadata, _Mapping]]] = ...) -> None: ...

class _ItemMetadataResponse(_message.Message):
    __slots__ = ["hit", "id", "metadata", "miss"]
    class _Hit(_message.Message):
        __slots__ = ["id", "metadata"]
        ID_FIELD_NUMBER: _ClassVar[int]
        METADATA_FIELD_NUMBER: _ClassVar[int]
        id: str
        metadata: _containers.RepeatedCompositeFieldContainer[_Metadata]
        def __init__(self, id: _Optional[str] = ..., metadata: _Optional[_Iterable[_Union[_Metadata, _Mapping]]] = ...) -> None: ...
    class _Miss(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    HIT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    MISS_FIELD_NUMBER: _ClassVar[int]
    hit: _ItemMetadataResponse._Hit
    id: str
    metadata: _containers.RepeatedCompositeFieldContainer[_Metadata]
    miss: _ItemMetadataResponse._Miss
    def __init__(self, miss: _Optional[_Union[_ItemMetadataResponse._Miss, _Mapping]] = ..., hit: _Optional[_Union[_ItemMetadataResponse._Hit, _Mapping]] = ..., id: _Optional[str] = ..., metadata: _Optional[_Iterable[_Union[_Metadata, _Mapping]]] = ...) -> None: ...

class _ItemResponse(_message.Message):
    __slots__ = ["hit", "id", "metadata", "miss", "vector"]
    class _Hit(_message.Message):
        __slots__ = ["id", "metadata", "vector"]
        ID_FIELD_NUMBER: _ClassVar[int]
        METADATA_FIELD_NUMBER: _ClassVar[int]
        VECTOR_FIELD_NUMBER: _ClassVar[int]
        id: str
        metadata: _containers.RepeatedCompositeFieldContainer[_Metadata]
        vector: _Vector
        def __init__(self, id: _Optional[str] = ..., vector: _Optional[_Union[_Vector, _Mapping]] = ..., metadata: _Optional[_Iterable[_Union[_Metadata, _Mapping]]] = ...) -> None: ...
    class _Miss(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    HIT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    MISS_FIELD_NUMBER: _ClassVar[int]
    VECTOR_FIELD_NUMBER: _ClassVar[int]
    hit: _ItemResponse._Hit
    id: str
    metadata: _containers.RepeatedCompositeFieldContainer[_Metadata]
    miss: _ItemResponse._Miss
    vector: _Vector
    def __init__(self, miss: _Optional[_Union[_ItemResponse._Miss, _Mapping]] = ..., hit: _Optional[_Union[_ItemResponse._Hit, _Mapping]] = ..., id: _Optional[str] = ..., vector: _Optional[_Union[_Vector, _Mapping]] = ..., metadata: _Optional[_Iterable[_Union[_Metadata, _Mapping]]] = ...) -> None: ...

class _LessThanExpression(_message.Message):
    __slots__ = ["field", "float_value", "integer_value"]
    FIELD_FIELD_NUMBER: _ClassVar[int]
    FLOAT_VALUE_FIELD_NUMBER: _ClassVar[int]
    INTEGER_VALUE_FIELD_NUMBER: _ClassVar[int]
    field: str
    float_value: float
    integer_value: int
    def __init__(self, field: _Optional[str] = ..., integer_value: _Optional[int] = ..., float_value: _Optional[float] = ...) -> None: ...

class _LessThanOrEqualExpression(_message.Message):
    __slots__ = ["field", "float_value", "integer_value"]
    FIELD_FIELD_NUMBER: _ClassVar[int]
    FLOAT_VALUE_FIELD_NUMBER: _ClassVar[int]
    INTEGER_VALUE_FIELD_NUMBER: _ClassVar[int]
    field: str
    float_value: float
    integer_value: int
    def __init__(self, field: _Optional[str] = ..., integer_value: _Optional[int] = ..., float_value: _Optional[float] = ...) -> None: ...

class _ListContainsExpression(_message.Message):
    __slots__ = ["field", "string_value"]
    FIELD_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUE_FIELD_NUMBER: _ClassVar[int]
    field: str
    string_value: str
    def __init__(self, field: _Optional[str] = ..., string_value: _Optional[str] = ...) -> None: ...

class _Metadata(_message.Message):
    __slots__ = ["boolean_value", "double_value", "field", "integer_value", "list_of_strings_value", "string_value"]
    class _ListOfStrings(_message.Message):
        __slots__ = ["values"]
        VALUES_FIELD_NUMBER: _ClassVar[int]
        values: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, values: _Optional[_Iterable[str]] = ...) -> None: ...
    BOOLEAN_VALUE_FIELD_NUMBER: _ClassVar[int]
    DOUBLE_VALUE_FIELD_NUMBER: _ClassVar[int]
    FIELD_FIELD_NUMBER: _ClassVar[int]
    INTEGER_VALUE_FIELD_NUMBER: _ClassVar[int]
    LIST_OF_STRINGS_VALUE_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUE_FIELD_NUMBER: _ClassVar[int]
    boolean_value: bool
    double_value: float
    field: str
    integer_value: int
    list_of_strings_value: _Metadata._ListOfStrings
    string_value: str
    def __init__(self, field: _Optional[str] = ..., string_value: _Optional[str] = ..., integer_value: _Optional[int] = ..., double_value: _Optional[float] = ..., boolean_value: bool = ..., list_of_strings_value: _Optional[_Union[_Metadata._ListOfStrings, _Mapping]] = ...) -> None: ...

class _MetadataRequest(_message.Message):
    __slots__ = ["all", "some"]
    class All(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    class Some(_message.Message):
        __slots__ = ["fields"]
        FIELDS_FIELD_NUMBER: _ClassVar[int]
        fields: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, fields: _Optional[_Iterable[str]] = ...) -> None: ...
    ALL_FIELD_NUMBER: _ClassVar[int]
    SOME_FIELD_NUMBER: _ClassVar[int]
    all: _MetadataRequest.All
    some: _MetadataRequest.Some
    def __init__(self, some: _Optional[_Union[_MetadataRequest.Some, _Mapping]] = ..., all: _Optional[_Union[_MetadataRequest.All, _Mapping]] = ...) -> None: ...

class _NoScoreThreshold(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _NotExpression(_message.Message):
    __slots__ = ["expression_to_negate"]
    EXPRESSION_TO_NEGATE_FIELD_NUMBER: _ClassVar[int]
    expression_to_negate: _FilterExpression
    def __init__(self, expression_to_negate: _Optional[_Union[_FilterExpression, _Mapping]] = ...) -> None: ...

class _OrExpression(_message.Message):
    __slots__ = ["first_expression", "second_expression"]
    FIRST_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    SECOND_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    first_expression: _FilterExpression
    second_expression: _FilterExpression
    def __init__(self, first_expression: _Optional[_Union[_FilterExpression, _Mapping]] = ..., second_expression: _Optional[_Union[_FilterExpression, _Mapping]] = ...) -> None: ...

class _SearchAndFetchVectorsHit(_message.Message):
    __slots__ = ["id", "metadata", "score", "vector"]
    ID_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    VECTOR_FIELD_NUMBER: _ClassVar[int]
    id: str
    metadata: _containers.RepeatedCompositeFieldContainer[_Metadata]
    score: float
    vector: _Vector
    def __init__(self, id: _Optional[str] = ..., score: _Optional[float] = ..., metadata: _Optional[_Iterable[_Union[_Metadata, _Mapping]]] = ..., vector: _Optional[_Union[_Vector, _Mapping]] = ...) -> None: ...

class _SearchAndFetchVectorsRequest(_message.Message):
    __slots__ = ["filter", "index_name", "metadata_fields", "no_score_threshold", "query_vector", "score_threshold", "top_k"]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    INDEX_NAME_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELDS_FIELD_NUMBER: _ClassVar[int]
    NO_SCORE_THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    QUERY_VECTOR_FIELD_NUMBER: _ClassVar[int]
    SCORE_THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    TOP_K_FIELD_NUMBER: _ClassVar[int]
    filter: _FilterExpression
    index_name: str
    metadata_fields: _MetadataRequest
    no_score_threshold: _NoScoreThreshold
    query_vector: _Vector
    score_threshold: float
    top_k: int
    def __init__(self, index_name: _Optional[str] = ..., top_k: _Optional[int] = ..., query_vector: _Optional[_Union[_Vector, _Mapping]] = ..., metadata_fields: _Optional[_Union[_MetadataRequest, _Mapping]] = ..., score_threshold: _Optional[float] = ..., no_score_threshold: _Optional[_Union[_NoScoreThreshold, _Mapping]] = ..., filter: _Optional[_Union[_FilterExpression, _Mapping]] = ...) -> None: ...

class _SearchAndFetchVectorsResponse(_message.Message):
    __slots__ = ["hits"]
    HITS_FIELD_NUMBER: _ClassVar[int]
    hits: _containers.RepeatedCompositeFieldContainer[_SearchAndFetchVectorsHit]
    def __init__(self, hits: _Optional[_Iterable[_Union[_SearchAndFetchVectorsHit, _Mapping]]] = ...) -> None: ...

class _SearchHit(_message.Message):
    __slots__ = ["id", "metadata", "score"]
    ID_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    id: str
    metadata: _containers.RepeatedCompositeFieldContainer[_Metadata]
    score: float
    def __init__(self, id: _Optional[str] = ..., score: _Optional[float] = ..., metadata: _Optional[_Iterable[_Union[_Metadata, _Mapping]]] = ...) -> None: ...

class _SearchRequest(_message.Message):
    __slots__ = ["filter", "index_name", "metadata_fields", "no_score_threshold", "query_vector", "score_threshold", "top_k"]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    INDEX_NAME_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELDS_FIELD_NUMBER: _ClassVar[int]
    NO_SCORE_THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    QUERY_VECTOR_FIELD_NUMBER: _ClassVar[int]
    SCORE_THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    TOP_K_FIELD_NUMBER: _ClassVar[int]
    filter: _FilterExpression
    index_name: str
    metadata_fields: _MetadataRequest
    no_score_threshold: _NoScoreThreshold
    query_vector: _Vector
    score_threshold: float
    top_k: int
    def __init__(self, index_name: _Optional[str] = ..., top_k: _Optional[int] = ..., query_vector: _Optional[_Union[_Vector, _Mapping]] = ..., metadata_fields: _Optional[_Union[_MetadataRequest, _Mapping]] = ..., score_threshold: _Optional[float] = ..., no_score_threshold: _Optional[_Union[_NoScoreThreshold, _Mapping]] = ..., filter: _Optional[_Union[_FilterExpression, _Mapping]] = ...) -> None: ...

class _SearchResponse(_message.Message):
    __slots__ = ["hits"]
    HITS_FIELD_NUMBER: _ClassVar[int]
    hits: _containers.RepeatedCompositeFieldContainer[_SearchHit]
    def __init__(self, hits: _Optional[_Iterable[_Union[_SearchHit, _Mapping]]] = ...) -> None: ...

class _UpsertItemBatchRequest(_message.Message):
    __slots__ = ["index_name", "items"]
    INDEX_NAME_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    index_name: str
    items: _containers.RepeatedCompositeFieldContainer[_Item]
    def __init__(self, index_name: _Optional[str] = ..., items: _Optional[_Iterable[_Union[_Item, _Mapping]]] = ...) -> None: ...

class _UpsertItemBatchResponse(_message.Message):
    __slots__ = ["error_indices"]
    ERROR_INDICES_FIELD_NUMBER: _ClassVar[int]
    error_indices: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, error_indices: _Optional[_Iterable[int]] = ...) -> None: ...

class _Vector(_message.Message):
    __slots__ = ["elements"]
    ELEMENTS_FIELD_NUMBER: _ClassVar[int]
    elements: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, elements: _Optional[_Iterable[float]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: controlclient.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63ontrolclient.proto\x12\x0e\x63ontrol_client\")\n\x13_CreateStoreRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\"\x16\n\x14_CreateStoreResponse\")\n\x13_DeleteStoreRequest\x12\x12\n\nstore_name\x18\x01 \x01(\t\"\x16\n\x14_DeleteStoreResponse\"(\n\x12_ListStoresRequest\x12\x12\n\nnext_token\x18\x01 \x01(\t\"P\n\x13_ListStoresResponse\x12%\n\x05store\x18\x01 \x03(\x0b\x32\x16.control_client._Store\x12\x12\n\nnext_token\x18\x02 \x01(\t\"\x1c\n\x06_Store\x12\x12\n\nstore_name\x18\x01 \x01(\t\"\xda\x02\n\x11_SimilarityMetric\x12V\n\x14\x65uclidean_similarity\x18\x01 \x01(\x0b\x32\x36.control_client._SimilarityMetric._EuclideanSimilarityH\x00\x12H\n\rinner_product\x18\x02 \x01(\x0b\x32/.control_client._SimilarityMetric._InnerProductH\x00\x12P\n\x11\x63osine_similarity\x18\x03 \x01(\x0b\x32\x33.control_client._SimilarityMetric._CosineSimilarityH\x00\x1a\x16\n\x14_EuclideanSimilarity\x1a\x0f\n\r_InnerProduct\x1a\x13\n\x11_CosineSimilarityB\x13\n\x11similarity_metric\"\x7f\n\x13_CreateIndexRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x16\n\x0enum_dimensions\x18\x02 \x01(\x04\x12<\n\x11similarity_metric\x18\x03 \x01(\x0b\x32!.control_client._SimilarityMetric\"\x16\n\x14_CreateIndexResponse\")\n\x13_DeleteIndexRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\"\x16\n\x14_DeleteIndexResponse\"\x15\n\x13_ListIndexesRequest\"\xc8\x01\n\x14_ListIndexesResponse\x12<\n\x07indexes\x18\x01 \x03(\x0b\x32+.control_client._ListIndexesResponse._Index\x1ar\n\x06_Index\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x16\n\x0enum_dimensions\x18\x02 \x01(\x04\x12<\n\x11similarity_metric\x18\x03 \x01(\x0b\x32!.control_client._SimilarityMetric\")\n\x13_DeleteCacheRequest\x12\x12\n\ncache_name\x18\x01 \x01(\t\"\x16\n\x14_DeleteCacheResponse\")\n\x13_CreateCacheRequest\x12\x12\n\ncache_name\x18\x01 \x01(\t\"\x16\n\x14_CreateCacheResponse\"(\n\x12_ListCachesRequest\x12\x12\n\nnext_token\x18\x01 \x01(\t\"x\n\x0c_CacheLimits\x12\x18\n\x10max_traffic_rate\x18\x01 \x01(\r\x12\x1b\n\x13max_throughput_kbps\x18\x02 \x01(\r\x12\x18\n\x10max_item_size_kb\x18\x03 \x01(\r\x12\x17\n\x0fmax_ttl_seconds\x18\x04 \x01(\x04\"m\n\x0c_TopicLimits\x12\x18\n\x10max_publish_rate\x18\x01 \x01(\r\x12\x1e\n\x16max_subscription_count\x18\x02 \x01(\r\x12#\n\x1bmax_publish_message_size_kb\x18\x03 \x01(\r\"\x84\x01\n\x06_Cache\x12\x12\n\ncache_name\x18\x01 \x01(\t\x12\x32\n\x0c\x63\x61\x63he_limits\x18\x02 \x01(\x0b\x32\x1c.control_client._CacheLimits\x12\x32\n\x0ctopic_limits\x18\x03 \x01(\x0b\x32\x1c.control_client._TopicLimits\"P\n\x13_ListCachesResponse\x12%\n\x05\x63\x61\x63he\x18\x01 \x03(\x0b\x32\x16.control_client._Cache\x12\x12\n\nnext_token\x18\x02 \x01(\t\"/\n\x18_CreateSigningKeyRequest\x12\x13\n\x0bttl_minutes\x18\x01 \x01(\r\"<\n\x19_CreateSigningKeyResponse\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nexpires_at\x18\x02 \x01(\x04\"*\n\x18_RevokeSigningKeyRequest\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"\x1b\n\x19_RevokeSigningKeyResponse\"1\n\x0b_SigningKey\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x12\n\nexpires_at\x18\x02 \x01(\x04\"-\n\x17_ListSigningKeysRequest\x12\x12\n\nnext_token\x18\x01 \x01(\t\"`\n\x18_ListSigningKeysResponse\x12\x30\n\x0bsigning_key\x18\x01 \x03(\x0b\x32\x1b.control_client._SigningKey\x12\x12\n\nnext_token\x18\x02 \x01(\t\"(\n\x12_FlushCacheRequest\x12\x12\n\ncache_name\x18\x01 \x01(\t\"\x15\n\x13_FlushCacheResponse2\xd9\t\n\nScsControl\x12Z\n\x0b\x43reateCache\x12#.control_client._CreateCacheRequest\x1a$.control_client._CreateCacheResponse\"\x00\x12Z\n\x0b\x44\x65leteCache\x12#.control_client._DeleteCacheRequest\x1a$.control_client._DeleteCacheResponse\"\x00\x12W\n\nListCaches\x12\".control_client._ListCachesRequest\x1a#.control_client._ListCachesResponse\"\x00\x12W\n\nFlushCache\x12\".control_client._FlushCacheRequest\x1a#.control_client._FlushCacheResponse\"\x00\x12i\n\x10\x43reateSigningKey\x12(.control_client._CreateSigningKeyRequest\x1a).control_client._CreateSigningKeyResponse\"\x00\x12i\n\x10RevokeSigningKey\x12(.control_client._RevokeSigningKeyRequest\x1a).control_client._RevokeSigningKeyResponse\"\x00\x12\x66\n\x0fListSigningKeys\x12\'.control_client._ListSigningKeysRequest\x1a(.control_client._ListSigningKeysResponse\"\x00\x12Z\n\x0b\x43reateIndex\x12#.control_client._CreateIndexRequest\x1a$.control_client._CreateIndexResponse\"\x00\x12Z\n\x0b\x44\x65leteIndex\x12#.control_client._DeleteIndexRequest\x1a$.control_client._DeleteIndexResponse\"\x00\x12Z\n\x0bListIndexes\x12#.control_client._ListIndexesRequest\x1a$.control_client._ListIndexesResponse\"\x00\x12Z\n\x0b\x43reateStore\x12#.control_client._CreateStoreRequest\x1a$.control_client._CreateStoreResponse\"\x00\x12Z\n\x0b\x44\x65leteStore\x12#.control_client._DeleteStoreRequest\x1a$.control_client._DeleteStoreResponse\"\x00\x12W\n\nListStores\x12\".control_client._ListStoresRequest\x1a#.control_client._ListStoresResponse\"\x00\x42h\n\x13grpc.control_clientP\x01Z0github.com/momentohq/client-sdk-go;client_sdk_go\xaa\x02\x1cMomento.Protos.ControlClientb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'controlclient_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023grpc.control_clientP\001Z0github.com/momentohq/client-sdk-go;client_sdk_go\252\002\034Momento.Protos.ControlClient'
  __CREATESTOREREQUEST._serialized_start=39
  __CREATESTOREREQUEST._serialized_end=80
  __CREATESTORERESPONSE._serialized_start=82
  __CREATESTORERESPONSE._serialized_end=104
  __DELETESTOREREQUEST._serialized_start=106
  __DELETESTOREREQUEST._serialized_end=147
  __DELETESTORERESPONSE._serialized_start=149
  __DELETESTORERESPONSE._serialized_end=171
  __LISTSTORESREQUEST._serialized_start=173
  __LISTSTORESREQUEST._serialized_end=213
  __LISTSTORESRESPONSE._serialized_start=215
  __LISTSTORESRESPONSE._serialized_end=295
  __STORE._serialized_start=297
  __STORE._serialized_end=325
  __SIMILARITYMETRIC._serialized_start=328
  __SIMILARITYMETRIC._serialized_end=674
  __SIMILARITYMETRIC__EUCLIDEANSIMILARITY._serialized_start=593
  __SIMILARITYMETRIC__EUCLIDEANSIMILARITY._serialized_end=615
  __SIMILARITYMETRIC__INNERPRODUCT._serialized_start=617
  __SIMILARITYMETRIC__INNERPRODUCT._serialized_end=632
  __SIMILARITYMETRIC__COSINESIMILARITY._serialized_start=634
  __SIMILARITYMETRIC__COSINESIMILARITY._serialized_end=653
  __CREATEINDEXREQUEST._serialized_start=676
  __CREATEINDEXREQUEST._serialized_end=803
  __CREATEINDEXRESPONSE._serialized_start=805
  __CREATEINDEXRESPONSE._serialized_end=827
  __DELETEINDEXREQUEST._serialized_start=829
  __DELETEINDEXREQUEST._serialized_end=870
  __DELETEINDEXRESPONSE._serialized_start=872
  __DELETEINDEXRESPONSE._serialized_end=894
  __LISTINDEXESREQUEST._serialized_start=896
  __LISTINDEXESREQUEST._serialized_end=917
  __LISTINDEXESRESPONSE._serialized_start=920
  __LISTINDEXESRESPONSE._serialized_end=1120
  __LISTINDEXESRESPONSE__INDEX._serialized_start=1006
  __LISTINDEXESRESPONSE__INDEX._serialized_end=1120
  __DELETECACHEREQUEST._serialized_start=1122
  __DELETECACHEREQUEST._serialized_end=1163
  __DELETECACHERESPONSE._serialized_start=1165
  __DELETECACHERESPONSE._serialized_end=1187
  __CREATECACHEREQUEST._serialized_start=1189
  __CREATECACHEREQUEST._serialized_end=1230
  __CREATECACHERESPONSE._serialized_start=1232
  __CREATECACHERESPONSE._serialized_end=1254
  __LISTCACHESREQUEST._serialized_start=1256
  __LISTCACHESREQUEST._serialized_end=1296
  __CACHELIMITS._serialized_start=1298
  __CACHELIMITS._serialized_end=1418
  __TOPICLIMITS._serialized_start=1420
  __TOPICLIMITS._serialized_end=1529
  __CACHE._serialized_start=1532
  __CACHE._serialized_end=1664
  __LISTCACHESRESPONSE._serialized_start=1666
  __LISTCACHESRESPONSE._serialized_end=1746
  __CREATESIGNINGKEYREQUEST._serialized_start=1748
  __CREATESIGNINGKEYREQUEST._serialized_end=1795
  __CREATESIGNINGKEYRESPONSE._serialized_start=1797
  __CREATESIGNINGKEYRESPONSE._serialized_end=1857
  __REVOKESIGNINGKEYREQUEST._serialized_start=1859
  __REVOKESIGNINGKEYREQUEST._serialized_end=1901
  __REVOKESIGNINGKEYRESPONSE._serialized_start=1903
  __REVOKESIGNINGKEYRESPONSE._serialized_end=1930
  __SIGNINGKEY._serialized_start=1932
  __SIGNINGKEY._serialized_end=1981
  __LISTSIGNINGKEYSREQUEST._serialized_start=1983
  __LISTSIGNINGKEYSREQUEST._serialized_end=2028
  __LISTSIGNINGKEYSRESPONSE._serialized_start=2030
  __LISTSIGNINGKEYSRESPONSE._serialized_end=2126
  __FLUSHCACHEREQUEST._serialized_start=2128
  __FLUSHCACHEREQUEST._serialized_end=2168
  __FLUSHCACHERESPONSE._serialized_start=2170
  __FLUSHCACHERESPONSE._serialized_end=2191
  _SCSCONTROL._serialized_start=2194
  _SCSCONTROL._serialized_end=3435
# @@protoc_insertion_point(module_scope)
